Class: FastpixClient::DRMConfigurations

Inherits:
Object
  • Object
show all
Extended by:
T::Sig
Defined in:
lib/fastpix_client/drm_configurations.rb

Constant Summary collapse

API_ERROR_OCCURRED =
'API error occurred'
CONTENT_TYPE_JSON =
'application/json'
UNKNOWN_CONTENT_TYPE_ERROR =
'Unknown content type received'

Instance Method Summary collapse

Constructor Details

#initialize(sdk_config) ⇒ DRMConfigurations

Returns a new instance of DRMConfigurations.



54
55
56
57
# File 'lib/fastpix_client/drm_configurations.rb', line 54

def initialize(sdk_config)
  @sdk_configuration = sdk_config
  
end

Instance Method Details

#get_drm_configuration(offset: nil, limit: nil, timeout_ms: nil) ⇒ Object



76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
# File 'lib/fastpix_client/drm_configurations.rb', line 76

def get_drm_configuration(offset: nil, limit: nil, timeout_ms: nil)
  # get_drm_configuration - Get list of DRM configuration IDs
  # 
  # This endpoint retrieves the DRM configuration (DRM ID) associated with a workspace. It returns a list of DRM configurations, identified by a unique DRM ID, which is used for creating DRM encrypted asset.
  # 
  # **How it works:**
  # 1. Make a GET request to this endpoint.  
  # 2. Optionally use the `offset` and `limit` query parameters to paginate through the list of DRM configurations.  
  # 3. The response includes a list of DRM IDs and pagination metadata.
  # 
  # **Example:**  
  # A media service provider may retrieve DRM configuration for a workspace to create DRM content.
  # 
  # Related guide: <a href="https://fastpix.com/docs/video-security/set-up-drm-encryption">Manage DRM configuration</a>
  # 
  request = Models::Operations::GetDrmConfigurationRequest.new(
    offset: offset,
    limit: limit
  )
  url, params = @sdk_configuration.get_server_details
  base_url = Utils.template_url(url, params)
  url = "#{base_url}/on-demand/drm-configurations"
  headers = {}
  headers = T.cast(headers, T::Hash[String, String])
  query_params = Utils.get_query_params(Models::Operations::GetDrmConfigurationRequest, request, nil)
  headers['Accept'] = CONTENT_TYPE_JSON
  headers['user-agent'] = @sdk_configuration.user_agent

  security = @sdk_configuration.security_source&.call

  timeout = (timeout_ms.to_f / 1000) unless timeout_ms.nil?
  timeout ||= @sdk_configuration.timeout
  

  connection = @sdk_configuration.client

  hook_ctx = SDKHooks::HookContext.new(
    config: @sdk_configuration,
    base_url: base_url,
    oauth2_scopes: nil,
    operation_id: 'getDrmConfiguration',
    security_source: @sdk_configuration.security_source
  )

  error = T.let(nil, T.nilable(StandardError))
  http_response = T.let(nil, T.nilable(Faraday::Response))
  
  
  begin
    http_response = T.must(connection).get(url) do |req|
      req.headers.merge!(headers)
      req.options.timeout = timeout unless timeout.nil?
      req.params = query_params
      Utils.configure_request_security(req, security)

      @sdk_configuration.hooks.before_request(
        hook_ctx: SDKHooks::BeforeRequestHookContext.new(
          hook_ctx: hook_ctx
        ),
        request: req
      )
    end
  rescue StandardError => e
    error = e
  ensure
    http_response = apply_after_request_hooks(http_response, error, hook_ctx)
  end
  
  content_type = http_response.headers.fetch('Content-Type', 'application/octet-stream')
  if Utils.match_status_code(http_response.status, ['200'])
    if Utils.match_content_type(content_type, CONTENT_TYPE_JSON)
      http_response = @sdk_configuration.hooks.after_success(
        hook_ctx: SDKHooks::AfterSuccessHookContext.new(
          hook_ctx: hook_ctx
        ),
        response: http_response
      )
      response_data = http_response.env.response_body
      obj = Crystalline.unmarshal_json(JSON.parse(response_data), Models::Operations::GetDrmConfigurationResponseBody)
      response = Models::Operations::GetDrmConfigurationResponse.new(
        status_code: http_response.status,
        content_type: content_type,
        raw_response: http_response,
        object: T.unsafe(obj)
      )

      return response
    else
      raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), UNKNOWN_CONTENT_TYPE_ERROR
    end
  elsif Utils.match_status_code(http_response.status, ['4XX'])
    raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), API_ERROR_OCCURRED
  elsif Utils.match_status_code(http_response.status, ['5XX'])
    raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), API_ERROR_OCCURRED
  else
    if Utils.match_content_type(content_type, CONTENT_TYPE_JSON)
      http_response = @sdk_configuration.hooks.after_success(
        hook_ctx: SDKHooks::AfterSuccessHookContext.new(
          hook_ctx: hook_ctx
        ),
        response: http_response
      )
      response_data = http_response.env.response_body
      obj = Crystalline.unmarshal_json(JSON.parse(response_data), Models::Components::DefaultError)
      response = Models::Operations::GetDrmConfigurationResponse.new(
        status_code: http_response.status,
        content_type: content_type,
        raw_response: http_response,
        default_error: T.unsafe(obj)
      )

      return response
    else
      raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), UNKNOWN_CONTENT_TYPE_ERROR
    end
  end
end

#get_drm_configuration_by_id(drm_configuration_id:, timeout_ms: nil) ⇒ Object



196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
# File 'lib/fastpix_client/drm_configurations.rb', line 196

def get_drm_configuration_by_id(drm_configuration_id:, timeout_ms: nil)
  # get_drm_configuration_by_id - Get DRM configuration by ID
  # 
  # This endpoint retrieves a DRM configuration ID. It is used to fetch the DRM-related ID for a workspace, typically required when validating or applying DRM policies to video assets.
  # 
  # **How it works:**
  # 1. Make a GET request to this endpoint, replacing `{drmConfigurationId}` with the UUID of the DRM configuration.  
  # 2. The response contains the associated DRM configuration ID.
  # 
  # Related guide: <a href="https://fastpix.com/docs/video-security/set-up-drm-encryption">Manage DRM configuration</a>
  # 
  request = Models::Operations::GetDrmConfigurationByIdRequest.new(
    drm_configuration_id: drm_configuration_id
  )
  url, params = @sdk_configuration.get_server_details
  base_url = Utils.template_url(url, params)
  url = Utils.generate_url(
    Models::Operations::GetDrmConfigurationByIdRequest,
    base_url,
    '/on-demand/drm-configurations/{drmConfigurationId}',
    request
  )
  headers = {}
  headers = T.cast(headers, T::Hash[String, String])
  headers['Accept'] = CONTENT_TYPE_JSON
  headers['user-agent'] = @sdk_configuration.user_agent

  security = @sdk_configuration.security_source&.call

  timeout = (timeout_ms.to_f / 1000) unless timeout_ms.nil?
  timeout ||= @sdk_configuration.timeout
  

  connection = @sdk_configuration.client

  hook_ctx = SDKHooks::HookContext.new(
    config: @sdk_configuration,
    base_url: base_url,
    oauth2_scopes: nil,
    operation_id: 'getDrmConfigurationById',
    security_source: @sdk_configuration.security_source
  )

  error = T.let(nil, T.nilable(StandardError))
  http_response = T.let(nil, T.nilable(Faraday::Response))
  
  
  begin
    http_response = T.must(connection).get(url) do |req|
      req.headers.merge!(headers)
      req.options.timeout = timeout unless timeout.nil?
      Utils.configure_request_security(req, security)

      @sdk_configuration.hooks.before_request(
        hook_ctx: SDKHooks::BeforeRequestHookContext.new(
          hook_ctx: hook_ctx
        ),
        request: req
      )
    end
  rescue StandardError => e
    error = e
  ensure
    http_response = apply_after_request_hooks(http_response, error, hook_ctx)
  end
  
  content_type = http_response.headers.fetch('Content-Type', 'application/octet-stream')
  if Utils.match_status_code(http_response.status, ['200'])
    if Utils.match_content_type(content_type, CONTENT_TYPE_JSON)
      http_response = @sdk_configuration.hooks.after_success(
        hook_ctx: SDKHooks::AfterSuccessHookContext.new(
          hook_ctx: hook_ctx
        ),
        response: http_response
      )
      response_data = http_response.env.response_body
      obj = Crystalline.unmarshal_json(JSON.parse(response_data), Models::Operations::GetDrmConfigurationByIdResponseBody)
      response = Models::Operations::GetDrmConfigurationByIdResponse.new(
        status_code: http_response.status,
        content_type: content_type,
        raw_response: http_response,
        object: T.unsafe(obj)
      )

      return response
    else
      raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), UNKNOWN_CONTENT_TYPE_ERROR
    end
  elsif Utils.match_status_code(http_response.status, ['4XX'])
    raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), API_ERROR_OCCURRED
  elsif Utils.match_status_code(http_response.status, ['5XX'])
    raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), API_ERROR_OCCURRED
  else
    if Utils.match_content_type(content_type, CONTENT_TYPE_JSON)
      http_response = @sdk_configuration.hooks.after_success(
        hook_ctx: SDKHooks::AfterSuccessHookContext.new(
          hook_ctx: hook_ctx
        ),
        response: http_response
      )
      response_data = http_response.env.response_body
      obj = Crystalline.unmarshal_json(JSON.parse(response_data), Models::Components::DefaultError)
      response = Models::Operations::GetDrmConfigurationByIdResponse.new(
        status_code: http_response.status,
        content_type: content_type,
        raw_response: http_response,
        default_error: T.unsafe(obj)
      )

      return response
    else
      raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), UNKNOWN_CONTENT_TYPE_ERROR
    end
  end
end

#get_url(base_url:, url_variables: nil) ⇒ Object



60
61
62
63
64
65
66
67
68
69
70
71
72
# File 'lib/fastpix_client/drm_configurations.rb', line 60

def get_url(base_url:, url_variables: nil)
  sd_base_url, sd_options = @sdk_configuration.get_server_details

  if base_url.nil?
    base_url = sd_base_url
  end

  if url_variables.nil?
    url_variables = sd_options
  end

  return Utils.template_url base_url, url_variables
end