Class: FastpixClient::Errors

Inherits:
Object
  • Object
show all
Extended by:
T::Sig
Defined in:
lib/fastpix_client/errors.rb

Constant Summary collapse

CONTENT_TYPE_JSON =
'application/json'

Instance Method Summary collapse

Constructor Details

#initialize(sdk_config) ⇒ Errors

Returns a new instance of Errors.



52
53
54
55
# File 'lib/fastpix_client/errors.rb', line 52

def initialize(sdk_config)
  @sdk_configuration = sdk_config
  
end

Instance Method Details

#get_url(base_url:, url_variables: nil) ⇒ Object



58
59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/fastpix_client/errors.rb', line 58

def get_url(base_url:, url_variables: nil)
  sd_base_url, sd_options = @sdk_configuration.get_server_details

  if base_url.nil?
    base_url = sd_base_url
  end

  if url_variables.nil?
    url_variables = sd_options
  end

  return Utils.template_url base_url, url_variables
end

#list_errors(timespan: nil, filterby: nil, limit: nil, timeout_ms: nil) ⇒ Object



74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
# File 'lib/fastpix_client/errors.rb', line 74

def list_errors(timespan: nil, filterby: nil, limit: nil, timeout_ms: nil)
  # list_errors - List errors
  # This endpoint returns the total number of playback errors that occurred, along with the total number of views captured, based on the specified timespan and filters. It provides insights into the overall playback quality and helps identify potential issues that may impact viewer experience. 
  # 
  # 
  # #### Key fields in response
  # 
  # * **percentage:** The percentage of views affected by the specific error. 
  # * **uniqueViewersEffectedPercentage:** The percentage of unique viewers affected by the specific error (available only in the topErrors section). 
  # * **notes:** Additional notes or information about the specific error. 
  # * **message:** The error message or description. 
  # * **lastSeen:** The timestamp of when the error was last observed. 
  # * **id:** The unique identifier for the specific error. 
  # * **description:** A description of the specific error. 
  # * **count:** The number of occurrences of the specific error. 
  # * **code:** The error code associated with the specific error. 
  # 
  # 
  # Related guide: <a href="https://fastpix.com/docs/working-with-video-data/troubleshoot-playback-errors">Troubleshoot errors</a>
  # 
  request = Models::Operations::ListErrorsRequest.new(
    timespan: timespan,
    filterby: filterby,
    limit: limit
  )
  url, params = @sdk_configuration.get_server_details
  base_url = Utils.template_url(url, params)
  url = "#{base_url}/data/errors"
  headers = {}
  headers = T.cast(headers, T::Hash[String, String])
  query_params = Utils.get_query_params(Models::Operations::ListErrorsRequest, request, nil)
  headers['Accept'] = CONTENT_TYPE_JSON
  headers['user-agent'] = @sdk_configuration.user_agent

  security = @sdk_configuration.security_source&.call

  timeout = (timeout_ms.to_f / 1000) unless timeout_ms.nil?
  timeout ||= @sdk_configuration.timeout
  

  connection = @sdk_configuration.client

  hook_ctx = SDKHooks::HookContext.new(
    config: @sdk_configuration,
    base_url: base_url,
    oauth2_scopes: nil,
    operation_id: 'list_errors',
    security_source: @sdk_configuration.security_source
  )

  error = T.let(nil, T.nilable(StandardError))
  http_response = T.let(nil, T.nilable(Faraday::Response))
  
  
  begin
    http_response = T.must(connection).get(url) do |req|
      req.headers.merge!(headers)
      req.options.timeout = timeout unless timeout.nil?
      req.params = query_params
      Utils.configure_request_security(req, security)

      @sdk_configuration.hooks.before_request(
        hook_ctx: SDKHooks::BeforeRequestHookContext.new(
          hook_ctx: hook_ctx
        ),
        request: req
      )
    end
  rescue StandardError => e
    error = e
  ensure
    http_response = apply_after_request_hooks(http_response, error, hook_ctx)
  end
  
  content_type = http_response.headers.fetch('Content-Type', 'application/octet-stream')
  if Utils.match_status_code(http_response.status, ['200'])
    if Utils.match_content_type(content_type, CONTENT_TYPE_JSON)
      http_response = @sdk_configuration.hooks.after_success(
        hook_ctx: SDKHooks::AfterSuccessHookContext.new(
          hook_ctx: hook_ctx
        ),
        response: http_response
      )
      response_data = http_response.env.response_body
      obj = Crystalline.unmarshal_json(JSON.parse(response_data), Models::Operations::ListErrorsResponseBody)
      response = Models::Operations::ListErrorsResponse.new(
        status_code: http_response.status,
        content_type: content_type,
        raw_response: http_response,
        object: T.unsafe(obj)
      )

      return response
    else
      raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), 'Unknown content type received'
    end
  elsif Utils.match_status_code(http_response.status, ['4XX'])
    raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), 'API error occurred'
  elsif Utils.match_status_code(http_response.status, ['5XX'])
    raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), 'API error occurred'
  else
    if Utils.match_content_type(content_type, CONTENT_TYPE_JSON)
      http_response = @sdk_configuration.hooks.after_success(
        hook_ctx: SDKHooks::AfterSuccessHookContext.new(
          hook_ctx: hook_ctx
        ),
        response: http_response
      )
      response_data = http_response.env.response_body
      obj = Crystalline.unmarshal_json(JSON.parse(response_data), Models::Components::DefaultError)
      response = Models::Operations::ListErrorsResponse.new(
        status_code: http_response.status,
        content_type: content_type,
        raw_response: http_response,
        default_error: T.unsafe(obj)
      )

      return response
    else
      raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), 'Unknown content type received'
    end
  end
end