Class: FastpixClient::InputVideo

Inherits:
Object
  • Object
show all
Extended by:
T::Sig
Defined in:
lib/fastpix_client/input_video.rb

Constant Summary collapse

API_ERROR_OCCURRED =
'API error occurred'
CONTENT_TYPE_JSON =
'application/json'
UNKNOWN_CONTENT_TYPE_ERROR =
'Unknown content type received'

Instance Method Summary collapse

Constructor Details

#initialize(sdk_config) ⇒ InputVideo

Returns a new instance of InputVideo.



69
70
71
72
# File 'lib/fastpix_client/input_video.rb', line 69

def initialize(sdk_config)
  @sdk_configuration = sdk_config
  
end

Instance Method Details

#create_media(request:, timeout_ms: nil) ⇒ Object



91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
# File 'lib/fastpix_client/input_video.rb', line 91

def create_media(request:, timeout_ms: nil)
  # create_media - Create media from URL
  # This endpoint allows developers or users to create a new video or audio media in FastPix using a publicly accessible URL. FastPix fetches the media from the provided URL, processes it, and stores it on the platform for use.
  # 
  # 
  # 
  # #### Public URL requirement:
  # 
  # 
  #   The provided URL must be publicly accessible and must point to a video stored in one of the following supported formats: .m4v, .ogv, .mpeg, .mov, .3gp, .f4v, .rm, .ts, .wtv, .avi, .mp4, .wmv, .webm, .mts, .vob, .mxf, asf, m2ts 
  # 
  # 
  # 
  # #### Supported storage types:
  # 
  # The URL can originate from various cloud storage services or content delivery networks (CDNs) such as: 
  # 
  # 
  # * **Amazon S3:** URLs from Amazon's Simple Storage Service. 
  # 
  # * **Google Cloud Storage:** URLs from Google Cloud's storage solution. 
  # 
  # * **Azure Blob Storage:** URLs from Microsoft's Azure storage. 
  # 
  # * **Public CDNs:** URLs from public content delivery networks that host video files. 
  # 
  # Upon successful creation, the API returns an `id` that must be retained for future operations related to this media. 
  # 
  # #### How it works
  # 
  # 
  # 1. Send a POST request to this endpoint with the media URL (typically a video or audio file) and optional media settings. 
  # 
  # 2. FastPix uploads the video from the provided URL to its storage. 
  # 
  # 3. Receive a response containing the unique id for the newly created media item. 
  # 
  # 4. Use the id in subsequent API calls, such as checking the status of the media with the <a href="https://fastpix.com/docs/video-on-demand-api/manage-videos/get-media">Get Media by ID</a> endpoint to determine when the media is ready for playback. 
  # 
  # FastPix uses webhooks to tell your application about things that happen in the background, outside of the API regular request flow. For instance, after the media file is created (but not yet processed or encoded), FastPix sends a `POST` request to your specified webhook URL with the event <a href="https://fastpix.com/docs/vod-events/media-events#videomediacreated">video.media.created</a>. 
  # 
  # 
  # After processing completes, monitor the events <a href="https://fastpix.com/docs/vod-events/media-events#videomediaready">video.media.ready</a> and <a href="https://fastpix.com/docs/vod-events/media-events#videomediafailed">video.media.failed</a> to track the status of the media file.
  # 
  # Related guide: <a href="https://fastpix.com/docs/upload-videos/upload-videos-from-a-url">Upload videos from URL</a>
  # 
  url, params = @sdk_configuration.get_server_details
  base_url = Utils.template_url(url, params)
  url = "#{base_url}/on-demand"
  headers = {}
  headers = T.cast(headers, T::Hash[String, String])
  req_content_type, data, form = Utils.serialize_request_body(request, false, false, :request, :json)
  headers['content-type'] = req_content_type
  body = encode_request_body(req_content_type, data, form)
  headers['Accept'] = CONTENT_TYPE_JSON
  headers['user-agent'] = @sdk_configuration.user_agent

  security = @sdk_configuration.security_source&.call

  timeout = (timeout_ms.to_f / 1000) unless timeout_ms.nil?
  timeout ||= @sdk_configuration.timeout
  

  connection = @sdk_configuration.client

  hook_ctx = SDKHooks::HookContext.new(
    config: @sdk_configuration,
    base_url: base_url,
    oauth2_scopes: nil,
    operation_id: 'create-media',
    security_source: @sdk_configuration.security_source
  )

  error = T.let(nil, T.nilable(StandardError))
  http_response = T.let(nil, T.nilable(Faraday::Response))
  
  
  begin
    http_response = T.must(connection).post(url) do |req|
      req.body = body
      req.headers.merge!(headers)
      req.options.timeout = timeout unless timeout.nil?
      Utils.configure_request_security(req, security)

      @sdk_configuration.hooks.before_request(
        hook_ctx: SDKHooks::BeforeRequestHookContext.new(
          hook_ctx: hook_ctx
        ),
        request: req
      )
    end
  rescue StandardError => e
    error = e
  ensure
    http_response = apply_after_request_hooks(http_response, error, hook_ctx)
  end
  
  content_type = http_response.headers.fetch('Content-Type', 'application/octet-stream')
  if Utils.match_status_code(http_response.status, ['201'])
    if Utils.match_content_type(content_type, CONTENT_TYPE_JSON)
      http_response = @sdk_configuration.hooks.after_success(
        hook_ctx: SDKHooks::AfterSuccessHookContext.new(
          hook_ctx: hook_ctx
        ),
        response: http_response
      )
      response_data = http_response.env.response_body
      obj = Crystalline.unmarshal_json(JSON.parse(response_data), Models::Components::CreateMediaSuccessResponse)
      response = Models::Operations::CreateMediaResponse.new(
        status_code: http_response.status,
        content_type: content_type,
        raw_response: http_response,
        create_media_success_response: T.unsafe(obj)
      )

      return response
    else
      raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), UNKNOWN_CONTENT_TYPE_ERROR
    end
  elsif Utils.match_status_code(http_response.status, ['4XX'])
    raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), API_ERROR_OCCURRED
  elsif Utils.match_status_code(http_response.status, ['5XX'])
    raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), API_ERROR_OCCURRED
  else
    if Utils.match_content_type(content_type, CONTENT_TYPE_JSON)
      http_response = @sdk_configuration.hooks.after_success(
        hook_ctx: SDKHooks::AfterSuccessHookContext.new(
          hook_ctx: hook_ctx
        ),
        response: http_response
      )
      response_data = http_response.env.response_body
      obj = Crystalline.unmarshal_json(JSON.parse(response_data), Models::Components::DefaultError)
      response = Models::Operations::CreateMediaResponse.new(
        status_code: http_response.status,
        content_type: content_type,
        raw_response: http_response,
        default_error: T.unsafe(obj)
      )

      return response
    else
      raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), UNKNOWN_CONTENT_TYPE_ERROR
    end
  end
end

#direct_upload_video_media(request:, timeout_ms: nil) ⇒ Object



240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
# File 'lib/fastpix_client/input_video.rb', line 240

def direct_upload_video_media(request:, timeout_ms: nil)
  # direct_upload_video_media - Upload media from device
  # This endpoint enables accelerated uploads of large media files directly from your local device to FastPix for processing and storage.
  # 
  # > **NOTE**
  # >
  # > This version now supports uploads with no file size limitations and offers faster uploads. The previous endpoint (which had a 500MB size limit) is now deprecated. You can find details in the [changelog](https://fastpix.com/docs/changelog/release-notes).
  # 
  # #### How it works
  # 
  # 1. Send a POST request to this endpoint with optional media settings.  
  # 
  # 2. The response includes an `uploadId` and a signed `url` for direct video file upload.
  # 
  # 3. Upload your video file to the provided url by making a PUT request. The API accepts the media file from your device and uploads it to the FastPix platform. (Refer to <a href="https://fastpix.com/docs/upload-videos/upload-videos-from-device#step-3-initiate-the-upload">Step 3: Initiate the upload</a> for complete instructions.)
  # 
  # 
  # 4. Once uploaded, the media undergoes processing and is assigned a unique ID for tracking. Retain this `uploadId` for any future operations related to this upload. 
  # 
  # 
  # 
  # After uploading, you can use the <a href="https://fastpix.com/docs/video-on-demand-api/manage-videos/get-media">Get Media by ID</a> endpoint to check the status of the uploaded media asset and see if it has transitioned to a `Ready` status for playback. 
  # 
  # To notify your application about the status of this API request check for the webhooks for <a href="https://fastpix.com/docs/webhooks/webhook-event-reference#media-related-events">media related events</a>.  
  # 
  # 
  # #### Example
  # 
  # A social media platform allows users to upload video content directly from their phones or computers. This endpoint facilitates the upload process. For example, if you are developing a video-sharing app where users can upload short clips from their mobile devices, this endpoint enables them to select a video, upload it to the platform.
  # 
  # Related guide: <a href="https://fastpix.com/docs/upload-videos/upload-videos-from-device">Upload videos directly</a>
  # 
  url, params = @sdk_configuration.get_server_details
  base_url = Utils.template_url(url, params)
  url = "#{base_url}/on-demand/upload"
  headers = {}
  headers = T.cast(headers, T::Hash[String, String])
  req_content_type, data, form = Utils.serialize_request_body(request, false, false, :request, :json)
  headers['content-type'] = req_content_type
  body = encode_request_body(req_content_type, data, form)
  headers['Accept'] = CONTENT_TYPE_JSON
  headers['user-agent'] = @sdk_configuration.user_agent

  security = @sdk_configuration.security_source&.call

  timeout = (timeout_ms.to_f / 1000) unless timeout_ms.nil?
  timeout ||= @sdk_configuration.timeout
  

  connection = @sdk_configuration.client

  hook_ctx = SDKHooks::HookContext.new(
    config: @sdk_configuration,
    base_url: base_url,
    oauth2_scopes: nil,
    operation_id: 'direct-upload-video-media',
    security_source: @sdk_configuration.security_source
  )

  error = T.let(nil, T.nilable(StandardError))
  http_response = T.let(nil, T.nilable(Faraday::Response))
  
  
  begin
    http_response = T.must(connection).post(url) do |req|
      req.body = body
      req.headers.merge!(headers)
      req.options.timeout = timeout unless timeout.nil?
      Utils.configure_request_security(req, security)

      @sdk_configuration.hooks.before_request(
        hook_ctx: SDKHooks::BeforeRequestHookContext.new(
          hook_ctx: hook_ctx
        ),
        request: req
      )
    end
  rescue StandardError => e
    error = e
  ensure
    http_response = apply_after_request_hooks(http_response, error, hook_ctx)
  end
  
  content_type = http_response.headers.fetch('Content-Type', 'application/octet-stream')
  if Utils.match_status_code(http_response.status, ['201'])
    if Utils.match_content_type(content_type, CONTENT_TYPE_JSON)
      http_response = @sdk_configuration.hooks.after_success(
        hook_ctx: SDKHooks::AfterSuccessHookContext.new(
          hook_ctx: hook_ctx
        ),
        response: http_response
      )
      response_data = http_response.env.response_body
      obj = Crystalline.unmarshal_json(JSON.parse(response_data), Models::Operations::DirectUploadVideoMediaResponseBody)
      response = Models::Operations::DirectUploadVideoMediaResponse.new(
        status_code: http_response.status,
        content_type: content_type,
        raw_response: http_response,
        object: T.unsafe(obj)
      )

      return response
    else
      raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), UNKNOWN_CONTENT_TYPE_ERROR
    end
  elsif Utils.match_status_code(http_response.status, ['4XX'])
    raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), API_ERROR_OCCURRED
  elsif Utils.match_status_code(http_response.status, ['5XX'])
    raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), API_ERROR_OCCURRED
  else
    if Utils.match_content_type(content_type, CONTENT_TYPE_JSON)
      http_response = @sdk_configuration.hooks.after_success(
        hook_ctx: SDKHooks::AfterSuccessHookContext.new(
          hook_ctx: hook_ctx
        ),
        response: http_response
      )
      response_data = http_response.env.response_body
      obj = Crystalline.unmarshal_json(JSON.parse(response_data), Models::Components::DefaultError)
      response = Models::Operations::DirectUploadVideoMediaResponse.new(
        status_code: http_response.status,
        content_type: content_type,
        raw_response: http_response,
        default_error: T.unsafe(obj)
      )

      return response
    else
      raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), UNKNOWN_CONTENT_TYPE_ERROR
    end
  end
end

#get_url(base_url:, url_variables: nil) ⇒ Object



75
76
77
78
79
80
81
82
83
84
85
86
87
# File 'lib/fastpix_client/input_video.rb', line 75

def get_url(base_url:, url_variables: nil)
  sd_base_url, sd_options = @sdk_configuration.get_server_details

  if base_url.nil?
    base_url = sd_base_url
  end

  if url_variables.nil?
    url_variables = sd_options
  end

  return Utils.template_url base_url, url_variables
end