Class: FastpixClient::LivePlayback

Inherits:
Object
  • Object
show all
Extended by:
T::Sig
Defined in:
lib/fastpix_client/live_playback.rb

Constant Summary collapse

API_ERROR_OCCURRED =
'API error occurred'
CONTENT_TYPE_HEADER =
'Content-Type'
CONTENT_TYPE_JSON =
'application/json'
DEFAULT_CONTENT_TYPE =
'application/octet-stream'
UNKNOWN_CONTENT_TYPE_ERROR =
'Unknown content type received'
USER_AGENT_HEADER =
'user-agent'

Instance Method Summary collapse

Constructor Details

#initialize(sdk_config) ⇒ LivePlayback

Returns a new instance of LivePlayback.



72
73
74
75
# File 'lib/fastpix_client/live_playback.rb', line 72

def initialize(sdk_config)
  @sdk_configuration = sdk_config
  
end

Instance Method Details

#create_playback_id_of_stream(body:, stream_id:, timeout_ms: nil) ⇒ Object



94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
# File 'lib/fastpix_client/live_playback.rb', line 94

def create_playback_id_of_stream(body:, stream_id:, timeout_ms: nil)
  # create_playback_id_of_stream - Create a playbackId
  # Generates a new playback ID for the live stream, allowing viewers to access the stream through this ID. The playback ID can be shared with viewers for direct access to the live broadcast. 
  # 
  #   By calling this endpoint with the `streamId`, FastPix returns a unique `playbackId`, which can be used to stream the live content. 
  # 
  #   #### Example
  # 
  #   A media platform needs to distribute a unique playback ID to users for an exclusive live concert. The platform can also embed the stream on various partner websites.
  request = Models::Operations::CreatePlaybackIdOfStreamRequest.new(
    stream_id: stream_id,
    body: body
  )
  url, params = @sdk_configuration.get_server_details
  base_url = Utils.template_url(url, params)
  url = Utils.generate_url(
    Models::Operations::CreatePlaybackIdOfStreamRequest,
    base_url,
    '/live/streams/{streamId}/playback-ids',
    request
  )
  headers = {}
  headers = T.cast(headers, T::Hash[String, String])
  req_content_type, data, form = Utils.serialize_request_body(request, false, false, :body, :json)
  headers['content-type'] = req_content_type
  body = encode_request_body(req_content_type, data, form)
  headers['Accept'] = CONTENT_TYPE_JSON
  headers[USER_AGENT_HEADER] = @sdk_configuration.user_agent

  security = @sdk_configuration.security_source&.call

  timeout = (timeout_ms.to_f / 1000) unless timeout_ms.nil?
  timeout ||= @sdk_configuration.timeout
  

  connection = @sdk_configuration.client

  hook_ctx = SDKHooks::HookContext.new(
    config: @sdk_configuration,
    base_url: base_url,
    oauth2_scopes: nil,
    operation_id: 'create-playbackId-of-stream',
    security_source: @sdk_configuration.security_source
  )

  error = T.let(nil, T.nilable(StandardError))
  http_response = T.let(nil, T.nilable(Faraday::Response))
  
  
  begin
    http_response = T.must(connection).post(url) do |req|
      req.body = body
      req.headers.merge!(headers)
      req.options.timeout = timeout unless timeout.nil?
      Utils.configure_request_security(req, security)

      @sdk_configuration.hooks.before_request(
        hook_ctx: SDKHooks::BeforeRequestHookContext.new(
          hook_ctx: hook_ctx
        ),
        request: req
      )
    end
  rescue StandardError => e
    error = e
  ensure
    http_response = apply_after_request_hooks(http_response, error, hook_ctx)
  end
  
  content_type = http_response.headers.fetch(CONTENT_TYPE_HEADER, DEFAULT_CONTENT_TYPE)
  if Utils.match_status_code(http_response.status, ['201'])
    if Utils.match_content_type(content_type, CONTENT_TYPE_JSON)
      http_response = @sdk_configuration.hooks.after_success(
        hook_ctx: SDKHooks::AfterSuccessHookContext.new(
          hook_ctx: hook_ctx
        ),
        response: http_response
      )
      response_data = http_response.env.response_body
      obj = Crystalline.unmarshal_json(JSON.parse(response_data), Models::Components::PlaybackIdSuccessResponse)
      response = Models::Operations::CreatePlaybackIdOfStreamResponse.new(
        status_code: http_response.status,
        content_type: content_type,
        raw_response: http_response,
        playback_id_success_response: T.unsafe(obj)
      )

      return response
    else
      raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), UNKNOWN_CONTENT_TYPE_ERROR
    end
  elsif Utils.match_status_code(http_response.status, ['4XX'])
    raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), API_ERROR_OCCURRED
  elsif Utils.match_status_code(http_response.status, ['5XX'])
    raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), API_ERROR_OCCURRED
  else
    if Utils.match_content_type(content_type, CONTENT_TYPE_JSON)
      http_response = @sdk_configuration.hooks.after_success(
        hook_ctx: SDKHooks::AfterSuccessHookContext.new(
          hook_ctx: hook_ctx
        ),
        response: http_response
      )
      response_data = http_response.env.response_body
      obj = Crystalline.unmarshal_json(JSON.parse(response_data), Models::Components::DefaultError)
      response = Models::Operations::CreatePlaybackIdOfStreamResponse.new(
        status_code: http_response.status,
        content_type: content_type,
        raw_response: http_response,
        default_error: T.unsafe(obj)
      )

      return response
    else
      raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), UNKNOWN_CONTENT_TYPE_ERROR
    end
  end
end

#delete_playback_id_of_stream(stream_id:, playback_id:, timeout_ms: nil) ⇒ Object



215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
# File 'lib/fastpix_client/live_playback.rb', line 215

def delete_playback_id_of_stream(stream_id:, playback_id:, timeout_ms: nil)
  # delete_playback_id_of_stream - Delete a playbackId
  # Deletes a previously created playback ID for a live stream.This prevents new viewers from accessing the stream using the playback ID, while current viewers can continue watching for a short period before the connection ends. FastPix deletes the ID and ensures the new playback request fails.
  # 
  # #### Example
  # A streaming service wants to prevent new users from joining a live stream that is nearing its end. The host can delete the playback ID to ensure no one can join the stream or replay it once it ends.
  request = Models::Operations::DeletePlaybackIdOfStreamRequest.new(
    stream_id: stream_id,
    playback_id: playback_id
  )
  url, params = @sdk_configuration.get_server_details
  base_url = Utils.template_url(url, params)
  url = Utils.generate_url(
    Models::Operations::DeletePlaybackIdOfStreamRequest,
    base_url,
    '/live/streams/{streamId}/playback-ids',
    request
  )
  headers = {}
  headers = T.cast(headers, T::Hash[String, String])
  query_params = Utils.get_query_params(Models::Operations::DeletePlaybackIdOfStreamRequest, request, nil)
  headers['Accept'] = CONTENT_TYPE_JSON
  headers[USER_AGENT_HEADER] = @sdk_configuration.user_agent

  security = @sdk_configuration.security_source&.call

  timeout = (timeout_ms.to_f / 1000) unless timeout_ms.nil?
  timeout ||= @sdk_configuration.timeout
  

  connection = @sdk_configuration.client

  hook_ctx = SDKHooks::HookContext.new(
    config: @sdk_configuration,
    base_url: base_url,
    oauth2_scopes: nil,
    operation_id: 'delete-playbackId-of-stream',
    security_source: @sdk_configuration.security_source
  )

  error = T.let(nil, T.nilable(StandardError))
  http_response = T.let(nil, T.nilable(Faraday::Response))
  
  
  begin
    http_response = T.must(connection).delete(url) do |req|
      req.headers.merge!(headers)
      req.options.timeout = timeout unless timeout.nil?
      req.params = query_params
      Utils.configure_request_security(req, security)

      @sdk_configuration.hooks.before_request(
        hook_ctx: SDKHooks::BeforeRequestHookContext.new(
          hook_ctx: hook_ctx
        ),
        request: req
      )
    end
  rescue StandardError => e
    error = e
  ensure
    http_response = apply_after_request_hooks(http_response, error, hook_ctx)
  end
  
  content_type = http_response.headers.fetch(CONTENT_TYPE_HEADER, DEFAULT_CONTENT_TYPE)
  if Utils.match_status_code(http_response.status, ['200'])
    if Utils.match_content_type(content_type, CONTENT_TYPE_JSON)
      http_response = @sdk_configuration.hooks.after_success(
        hook_ctx: SDKHooks::AfterSuccessHookContext.new(
          hook_ctx: hook_ctx
        ),
        response: http_response
      )
      response_data = http_response.env.response_body
      obj = Crystalline.unmarshal_json(JSON.parse(response_data), Models::Components::LiveStreamDeleteResponse)
      response = Models::Operations::DeletePlaybackIdOfStreamResponse.new(
        status_code: http_response.status,
        content_type: content_type,
        raw_response: http_response,
        live_stream_delete_response: T.unsafe(obj)
      )

      return response
    else
      raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), UNKNOWN_CONTENT_TYPE_ERROR
    end
  elsif Utils.match_status_code(http_response.status, ['4XX'])
    raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), API_ERROR_OCCURRED
  elsif Utils.match_status_code(http_response.status, ['5XX'])
    raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), API_ERROR_OCCURRED
  else
    if Utils.match_content_type(content_type, CONTENT_TYPE_JSON)
      http_response = @sdk_configuration.hooks.after_success(
        hook_ctx: SDKHooks::AfterSuccessHookContext.new(
          hook_ctx: hook_ctx
        ),
        response: http_response
      )
      response_data = http_response.env.response_body
      obj = Crystalline.unmarshal_json(JSON.parse(response_data), Models::Components::DefaultError)
      response = Models::Operations::DeletePlaybackIdOfStreamResponse.new(
        status_code: http_response.status,
        content_type: content_type,
        raw_response: http_response,
        default_error: T.unsafe(obj)
      )

      return response
    else
      raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), UNKNOWN_CONTENT_TYPE_ERROR
    end
  end
end

#get_live_stream_playback_id(stream_id:, playback_id:, timeout_ms: nil) ⇒ Object



331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
# File 'lib/fastpix_client/live_playback.rb', line 331

def get_live_stream_playback_id(stream_id:, playback_id:, timeout_ms: nil)
  # get_live_stream_playback_id - Get playbackId details
  # Retrieves details for an existing playback ID. When you provide the playbackId returned from a previous stream or playback creation request, FastPix returns the associated playback information, including the access policy.
  # 
  # #### Example
  # A developer needs to confirm the access policy of the playback ID to ensure whether the stream is public or private for viewers.
  request = Models::Operations::GetLiveStreamPlaybackIdRequest.new(
    stream_id: stream_id,
    playback_id: playback_id
  )
  url, params = @sdk_configuration.get_server_details
  base_url = Utils.template_url(url, params)
  url = Utils.generate_url(
    Models::Operations::GetLiveStreamPlaybackIdRequest,
    base_url,
    '/live/streams/{streamId}/playback-ids/{playbackId}',
    request
  )
  headers = {}
  headers = T.cast(headers, T::Hash[String, String])
  headers['Accept'] = CONTENT_TYPE_JSON
  headers[USER_AGENT_HEADER] = @sdk_configuration.user_agent

  security = @sdk_configuration.security_source&.call

  timeout = (timeout_ms.to_f / 1000) unless timeout_ms.nil?
  timeout ||= @sdk_configuration.timeout
  

  connection = @sdk_configuration.client

  hook_ctx = SDKHooks::HookContext.new(
    config: @sdk_configuration,
    base_url: base_url,
    oauth2_scopes: nil,
    operation_id: 'get-live-stream-playback-id',
    security_source: @sdk_configuration.security_source
  )

  error = T.let(nil, T.nilable(StandardError))
  http_response = T.let(nil, T.nilable(Faraday::Response))
  
  
  begin
    http_response = T.must(connection).get(url) do |req|
      req.headers.merge!(headers)
      req.options.timeout = timeout unless timeout.nil?
      Utils.configure_request_security(req, security)

      @sdk_configuration.hooks.before_request(
        hook_ctx: SDKHooks::BeforeRequestHookContext.new(
          hook_ctx: hook_ctx
        ),
        request: req
      )
    end
  rescue StandardError => e
    error = e
  ensure
    http_response = apply_after_request_hooks(http_response, error, hook_ctx)
  end
  
  content_type = http_response.headers.fetch(CONTENT_TYPE_HEADER, DEFAULT_CONTENT_TYPE)
  if Utils.match_status_code(http_response.status, ['200'])
    if Utils.match_content_type(content_type, CONTENT_TYPE_JSON)
      http_response = @sdk_configuration.hooks.after_success(
        hook_ctx: SDKHooks::AfterSuccessHookContext.new(
          hook_ctx: hook_ctx
        ),
        response: http_response
      )
      response_data = http_response.env.response_body
      obj = Crystalline.unmarshal_json(JSON.parse(response_data), Models::Components::PlaybackIdSuccessResponse)
      response = Models::Operations::GetLiveStreamPlaybackIdResponse.new(
        status_code: http_response.status,
        content_type: content_type,
        raw_response: http_response,
        playback_id_success_response: T.unsafe(obj)
      )

      return response
    else
      raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), UNKNOWN_CONTENT_TYPE_ERROR
    end
  elsif Utils.match_status_code(http_response.status, ['4XX'])
    raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), API_ERROR_OCCURRED
  elsif Utils.match_status_code(http_response.status, ['5XX'])
    raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), API_ERROR_OCCURRED
  else
    if Utils.match_content_type(content_type, CONTENT_TYPE_JSON)
      http_response = @sdk_configuration.hooks.after_success(
        hook_ctx: SDKHooks::AfterSuccessHookContext.new(
          hook_ctx: hook_ctx
        ),
        response: http_response
      )
      response_data = http_response.env.response_body
      obj = Crystalline.unmarshal_json(JSON.parse(response_data), Models::Components::DefaultError)
      response = Models::Operations::GetLiveStreamPlaybackIdResponse.new(
        status_code: http_response.status,
        content_type: content_type,
        raw_response: http_response,
        default_error: T.unsafe(obj)
      )

      return response
    else
      raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), UNKNOWN_CONTENT_TYPE_ERROR
    end
  end
end

#get_url(base_url:, url_variables: nil) ⇒ Object



78
79
80
81
82
83
84
85
86
87
88
89
90
# File 'lib/fastpix_client/live_playback.rb', line 78

def get_url(base_url:, url_variables: nil)
  sd_base_url, sd_options = @sdk_configuration.get_server_details

  if base_url.nil?
    base_url = sd_base_url
  end

  if url_variables.nil?
    url_variables = sd_options
  end

  return Utils.template_url base_url, url_variables
end