Class: FastpixClient::ManageLiveStream
- Inherits:
-
Object
- Object
- FastpixClient::ManageLiveStream
- Extended by:
- T::Sig
- Defined in:
- lib/fastpix_client/manage_live_stream.rb
Constant Summary collapse
- API_ERROR_OCCURRED =
'API error occurred'- CONTENT_TYPE_HEADER =
'Content-Type'- CONTENT_TYPE_JSON =
'application/json'- DEFAULT_CONTENT_TYPE =
'application/octet-stream'- STREAM_PATH =
'/live/streams/{streamId}'- UNKNOWN_CONTENT_TYPE_ERROR =
'Unknown content type received'- USER_AGENT_HEADER =
'user-agent'
Instance Method Summary collapse
- #complete_live_stream(stream_id:, timeout_ms: nil) ⇒ Object
- #delete_live_stream(stream_id:, timeout_ms: nil) ⇒ Object
- #disable_live_stream(stream_id:, timeout_ms: nil) ⇒ Object
- #enable_live_stream(stream_id:, timeout_ms: nil) ⇒ Object
- #get_all_streams(limit: nil, offset: nil, order_by: nil, timeout_ms: nil) ⇒ Object
- #get_live_stream_by_id(stream_id:, timeout_ms: nil) ⇒ Object
- #get_live_stream_viewer_count_by_id(stream_id:, timeout_ms: nil) ⇒ Object
- #get_url(base_url:, url_variables: nil) ⇒ Object
-
#initialize(sdk_config) ⇒ ManageLiveStream
constructor
A new instance of ManageLiveStream.
- #update_live_stream(body:, stream_id:, timeout_ms: nil) ⇒ Object
Constructor Details
#initialize(sdk_config) ⇒ ManageLiveStream
Returns a new instance of ManageLiveStream.
73 74 75 76 |
# File 'lib/fastpix_client/manage_live_stream.rb', line 73 def initialize(sdk_config) @sdk_configuration = sdk_config end |
Instance Method Details
#complete_live_stream(stream_id:, timeout_ms: nil) ⇒ Object
926 927 928 929 930 931 932 933 934 935 936 937 938 939 940 941 942 943 944 945 946 947 948 949 950 951 952 953 954 955 956 957 958 959 960 961 962 963 964 965 966 967 968 969 970 971 972 973 974 975 976 977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 1042 |
# File 'lib/fastpix_client/manage_live_stream.rb', line 926 def complete_live_stream(stream_id:, timeout_ms: nil) # complete_live_stream - Complete a stream # This endpoint marks a livestream as completed by stopping the active stream and transitioning its status to `idle`. It is typically used after a livestream session has ended. # # This operation only works when the stream is in the `active` state. # # Completing a stream can help finalize the session and trigger post-processing events like VOD generation. # # #### Example # # A virtual event ends, and the system or host needs to close the livestream to prevent further streaming. This endpoint ensures the livestream status is changed from `active` to `idle`, indicating it's officially completed. # # Related guide <a href="https://fastpix.com/docs/manage-live-streams/create-and-manage-live-streams">Manage streams</a> request = Models::Operations::CompleteLiveStreamRequest.new( stream_id: stream_id ) url, params = @sdk_configuration.get_server_details base_url = Utils.template_url(url, params) url = Utils.generate_url( Models::Operations::CompleteLiveStreamRequest, base_url, '/live/streams/{streamId}/finish', request ) headers = {} headers = T.cast(headers, T::Hash[String, String]) headers['Accept'] = CONTENT_TYPE_JSON headers[USER_AGENT_HEADER] = @sdk_configuration.user_agent security = @sdk_configuration.security_source&.call timeout = (timeout_ms.to_f / 1000) unless timeout_ms.nil? timeout ||= @sdk_configuration.timeout connection = @sdk_configuration.client hook_ctx = SDKHooks::HookContext.new( config: @sdk_configuration, base_url: base_url, oauth2_scopes: nil, operation_id: 'complete-live-stream', security_source: @sdk_configuration.security_source ) error = T.let(nil, T.nilable(StandardError)) http_response = T.let(nil, T.nilable(Faraday::Response)) begin http_response = T.must(connection).put(url) do |req| req.headers.merge!(headers) req..timeout = timeout unless timeout.nil? Utils.configure_request_security(req, security) @sdk_configuration.hooks.before_request( hook_ctx: SDKHooks::BeforeRequestHookContext.new( hook_ctx: hook_ctx ), request: req ) end rescue StandardError => e error = e ensure http_response = apply_after_request_hooks(http_response, error, hook_ctx) end content_type = http_response.headers.fetch(CONTENT_TYPE_HEADER, DEFAULT_CONTENT_TYPE) if Utils.match_status_code(http_response.status, ['200']) if Utils.match_content_type(content_type, CONTENT_TYPE_JSON) http_response = @sdk_configuration.hooks.after_success( hook_ctx: SDKHooks::AfterSuccessHookContext.new( hook_ctx: hook_ctx ), response: http_response ) response_data = http_response.env.response_body obj = Crystalline.unmarshal_json(JSON.parse(response_data), Models::Components::LiveStreamDeleteResponse) response = Models::Operations::CompleteLiveStreamResponse.new( status_code: http_response.status, content_type: content_type, raw_response: http_response, live_stream_delete_response: T.unsafe(obj) ) return response else raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), UNKNOWN_CONTENT_TYPE_ERROR end elsif Utils.match_status_code(http_response.status, ['4XX']) raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), API_ERROR_OCCURRED elsif Utils.match_status_code(http_response.status, ['5XX']) raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), API_ERROR_OCCURRED else if Utils.match_content_type(content_type, CONTENT_TYPE_JSON) http_response = @sdk_configuration.hooks.after_success( hook_ctx: SDKHooks::AfterSuccessHookContext.new( hook_ctx: hook_ctx ), response: http_response ) response_data = http_response.env.response_body obj = Crystalline.unmarshal_json(JSON.parse(response_data), Models::Components::DefaultError) response = Models::Operations::CompleteLiveStreamResponse.new( status_code: http_response.status, content_type: content_type, raw_response: http_response, default_error: T.unsafe(obj) ) return response else raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), UNKNOWN_CONTENT_TYPE_ERROR end end end |
#delete_live_stream(stream_id:, timeout_ms: nil) ⇒ Object
443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 |
# File 'lib/fastpix_client/manage_live_stream.rb', line 443 def delete_live_stream(stream_id:, timeout_ms: nil) # delete_live_stream - Delete a stream # Permanently deletes a specified live stream from the workspace. If the stream is active, the encoder is disconnected and ingestion stops immediately. This action is irreversible, and any future playback attempts fail as a result. # # Provide the `streamId` in the request to terminate active connections and remove the stream from the workspace. You can further look for <a href="https://fastpix.com/docs/live-stream-events/live-events#videolive_streamdeleted">video.live_stream.deleted</a> webhook to notify your system about the status. # # #### Example # # For an online concert platform, a trial stream was mistakenly made public. The event manager deletes the stream before the concert begins to avoid confusion among viewers. # # # Related guide: <a href="https://fastpix.com/docs/manage-live-streams/create-and-manage-live-streams">Manage streams</a> request = Models::Operations::DeleteLiveStreamRequest.new( stream_id: stream_id ) url, params = @sdk_configuration.get_server_details base_url = Utils.template_url(url, params) url = Utils.generate_url( Models::Operations::DeleteLiveStreamRequest, base_url, STREAM_PATH, request ) headers = {} headers = T.cast(headers, T::Hash[String, String]) headers['Accept'] = CONTENT_TYPE_JSON headers[USER_AGENT_HEADER] = @sdk_configuration.user_agent security = @sdk_configuration.security_source&.call timeout = (timeout_ms.to_f / 1000) unless timeout_ms.nil? timeout ||= @sdk_configuration.timeout connection = @sdk_configuration.client hook_ctx = SDKHooks::HookContext.new( config: @sdk_configuration, base_url: base_url, oauth2_scopes: nil, operation_id: 'delete-live-stream', security_source: @sdk_configuration.security_source ) error = T.let(nil, T.nilable(StandardError)) http_response = T.let(nil, T.nilable(Faraday::Response)) begin http_response = T.must(connection).delete(url) do |req| req.headers.merge!(headers) req..timeout = timeout unless timeout.nil? Utils.configure_request_security(req, security) @sdk_configuration.hooks.before_request( hook_ctx: SDKHooks::BeforeRequestHookContext.new( hook_ctx: hook_ctx ), request: req ) end rescue StandardError => e error = e ensure http_response = apply_after_request_hooks(http_response, error, hook_ctx) end content_type = http_response.headers.fetch(CONTENT_TYPE_HEADER, DEFAULT_CONTENT_TYPE) if Utils.match_status_code(http_response.status, ['200']) if Utils.match_content_type(content_type, CONTENT_TYPE_JSON) http_response = @sdk_configuration.hooks.after_success( hook_ctx: SDKHooks::AfterSuccessHookContext.new( hook_ctx: hook_ctx ), response: http_response ) response_data = http_response.env.response_body obj = Crystalline.unmarshal_json(JSON.parse(response_data), Models::Components::LiveStreamDeleteResponse) response = Models::Operations::DeleteLiveStreamResponse.new( status_code: http_response.status, content_type: content_type, raw_response: http_response, live_stream_delete_response: T.unsafe(obj) ) return response else raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), UNKNOWN_CONTENT_TYPE_ERROR end elsif Utils.match_status_code(http_response.status, ['4XX']) raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), API_ERROR_OCCURRED elsif Utils.match_status_code(http_response.status, ['5XX']) raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), API_ERROR_OCCURRED else if Utils.match_content_type(content_type, CONTENT_TYPE_JSON) http_response = @sdk_configuration.hooks.after_success( hook_ctx: SDKHooks::AfterSuccessHookContext.new( hook_ctx: hook_ctx ), response: http_response ) response_data = http_response.env.response_body obj = Crystalline.unmarshal_json(JSON.parse(response_data), Models::Components::DefaultError) response = Models::Operations::DeleteLiveStreamResponse.new( status_code: http_response.status, content_type: content_type, raw_response: http_response, default_error: T.unsafe(obj) ) return response else raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), UNKNOWN_CONTENT_TYPE_ERROR end end end |
#disable_live_stream(stream_id:, timeout_ms: nil) ⇒ Object
808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 868 869 870 871 872 873 874 875 876 877 878 879 880 881 882 883 884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 |
# File 'lib/fastpix_client/manage_live_stream.rb', line 808 def disable_live_stream(stream_id:, timeout_ms: nil) # disable_live_stream - Disable a stream # This endpoint disables a livestream by setting its status to `disabled`. Use this to stop a livestream when it's no longer needed or must be taken offline intentionally. # # A disabled stream can later be re-enabled using the enable endpoint — however, if you're on a trial plan, re-enabling is not allowed once the stream is disabled. # # #### Example # # A speaker finishes their live session and wants to prevent the stream from being mistakenly started again. By calling this endpoint, the stream is transitioned to a `disabled` state, ensuring it's permanently stopped (unless re-enabled on a paid plan). # # Related guide <a href="https://fastpix.com/docs/manage-live-streams/create-and-manage-live-streams">Manage streams</a> request = Models::Operations::DisableLiveStreamRequest.new( stream_id: stream_id ) url, params = @sdk_configuration.get_server_details base_url = Utils.template_url(url, params) url = Utils.generate_url( Models::Operations::DisableLiveStreamRequest, base_url, '/live/streams/{streamId}/live-disable', request ) headers = {} headers = T.cast(headers, T::Hash[String, String]) headers['Accept'] = CONTENT_TYPE_JSON headers[USER_AGENT_HEADER] = @sdk_configuration.user_agent security = @sdk_configuration.security_source&.call timeout = (timeout_ms.to_f / 1000) unless timeout_ms.nil? timeout ||= @sdk_configuration.timeout connection = @sdk_configuration.client hook_ctx = SDKHooks::HookContext.new( config: @sdk_configuration, base_url: base_url, oauth2_scopes: nil, operation_id: 'disable-live-stream', security_source: @sdk_configuration.security_source ) error = T.let(nil, T.nilable(StandardError)) http_response = T.let(nil, T.nilable(Faraday::Response)) begin http_response = T.must(connection).put(url) do |req| req.headers.merge!(headers) req..timeout = timeout unless timeout.nil? Utils.configure_request_security(req, security) @sdk_configuration.hooks.before_request( hook_ctx: SDKHooks::BeforeRequestHookContext.new( hook_ctx: hook_ctx ), request: req ) end rescue StandardError => e error = e ensure http_response = apply_after_request_hooks(http_response, error, hook_ctx) end content_type = http_response.headers.fetch(CONTENT_TYPE_HEADER, DEFAULT_CONTENT_TYPE) if Utils.match_status_code(http_response.status, ['200']) if Utils.match_content_type(content_type, CONTENT_TYPE_JSON) http_response = @sdk_configuration.hooks.after_success( hook_ctx: SDKHooks::AfterSuccessHookContext.new( hook_ctx: hook_ctx ), response: http_response ) response_data = http_response.env.response_body obj = Crystalline.unmarshal_json(JSON.parse(response_data), Models::Components::LiveStreamDeleteResponse) response = Models::Operations::DisableLiveStreamResponse.new( status_code: http_response.status, content_type: content_type, raw_response: http_response, live_stream_delete_response: T.unsafe(obj) ) return response else raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), UNKNOWN_CONTENT_TYPE_ERROR end elsif Utils.match_status_code(http_response.status, ['4XX']) raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), API_ERROR_OCCURRED elsif Utils.match_status_code(http_response.status, ['5XX']) raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), API_ERROR_OCCURRED else if Utils.match_content_type(content_type, CONTENT_TYPE_JSON) http_response = @sdk_configuration.hooks.after_success( hook_ctx: SDKHooks::AfterSuccessHookContext.new( hook_ctx: hook_ctx ), response: http_response ) response_data = http_response.env.response_body obj = Crystalline.unmarshal_json(JSON.parse(response_data), Models::Components::DefaultError) response = Models::Operations::DisableLiveStreamResponse.new( status_code: http_response.status, content_type: content_type, raw_response: http_response, default_error: T.unsafe(obj) ) return response else raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), UNKNOWN_CONTENT_TYPE_ERROR end end end |
#enable_live_stream(stream_id:, timeout_ms: nil) ⇒ Object
688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 791 792 793 794 795 796 797 798 799 800 801 802 803 804 |
# File 'lib/fastpix_client/manage_live_stream.rb', line 688 def enable_live_stream(stream_id:, timeout_ms: nil) # enable_live_stream - Enable a stream # This endpoint allows you to enable a livestream by transitioning its status from `disabled` to `idle`. After it is enabled, the stream becomes available and ready to accept an incoming broadcast from a streaming tool. # # Streams on the trial plan cannot be re-enabled if they are in the `disabled` state. # # The `livestreamId` must be provided in the path, and the stream must not already be in an enabled state (`idle`, `preparing`, or `active`). # # #### Example # # A creator disables a livestream to pause it temporarily. Later, they decide to continue the session. By calling this endpoint with the stream's ID, they can re-enable and restart the same livestream. # # Related guide <a href="https://fastpix.com/docs/manage-live-streams/create-and-manage-live-streams">Manage streams</a> request = Models::Operations::EnableLiveStreamRequest.new( stream_id: stream_id ) url, params = @sdk_configuration.get_server_details base_url = Utils.template_url(url, params) url = Utils.generate_url( Models::Operations::EnableLiveStreamRequest, base_url, '/live/streams/{streamId}/live-enable', request ) headers = {} headers = T.cast(headers, T::Hash[String, String]) headers['Accept'] = CONTENT_TYPE_JSON headers[USER_AGENT_HEADER] = @sdk_configuration.user_agent security = @sdk_configuration.security_source&.call timeout = (timeout_ms.to_f / 1000) unless timeout_ms.nil? timeout ||= @sdk_configuration.timeout connection = @sdk_configuration.client hook_ctx = SDKHooks::HookContext.new( config: @sdk_configuration, base_url: base_url, oauth2_scopes: nil, operation_id: 'enable-live-stream', security_source: @sdk_configuration.security_source ) error = T.let(nil, T.nilable(StandardError)) http_response = T.let(nil, T.nilable(Faraday::Response)) begin http_response = T.must(connection).put(url) do |req| req.headers.merge!(headers) req..timeout = timeout unless timeout.nil? Utils.configure_request_security(req, security) @sdk_configuration.hooks.before_request( hook_ctx: SDKHooks::BeforeRequestHookContext.new( hook_ctx: hook_ctx ), request: req ) end rescue StandardError => e error = e ensure http_response = apply_after_request_hooks(http_response, error, hook_ctx) end content_type = http_response.headers.fetch(CONTENT_TYPE_HEADER, DEFAULT_CONTENT_TYPE) if Utils.match_status_code(http_response.status, ['200']) if Utils.match_content_type(content_type, CONTENT_TYPE_JSON) http_response = @sdk_configuration.hooks.after_success( hook_ctx: SDKHooks::AfterSuccessHookContext.new( hook_ctx: hook_ctx ), response: http_response ) response_data = http_response.env.response_body obj = Crystalline.unmarshal_json(JSON.parse(response_data), Models::Components::LiveStreamDeleteResponse) response = Models::Operations::EnableLiveStreamResponse.new( status_code: http_response.status, content_type: content_type, raw_response: http_response, live_stream_delete_response: T.unsafe(obj) ) return response else raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), UNKNOWN_CONTENT_TYPE_ERROR end elsif Utils.match_status_code(http_response.status, ['4XX']) raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), API_ERROR_OCCURRED elsif Utils.match_status_code(http_response.status, ['5XX']) raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), API_ERROR_OCCURRED else if Utils.match_content_type(content_type, CONTENT_TYPE_JSON) http_response = @sdk_configuration.hooks.after_success( hook_ctx: SDKHooks::AfterSuccessHookContext.new( hook_ctx: hook_ctx ), response: http_response ) response_data = http_response.env.response_body obj = Crystalline.unmarshal_json(JSON.parse(response_data), Models::Components::DefaultError) response = Models::Operations::EnableLiveStreamResponse.new( status_code: http_response.status, content_type: content_type, raw_response: http_response, default_error: T.unsafe(obj) ) return response else raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), UNKNOWN_CONTENT_TYPE_ERROR end end end |
#get_all_streams(limit: nil, offset: nil, order_by: nil, timeout_ms: nil) ⇒ Object
95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 |
# File 'lib/fastpix_client/manage_live_stream.rb', line 95 def get_all_streams(limit: nil, offset: nil, order_by: nil, timeout_ms: nil) # get_all_streams - Get all live streams # Retrieves a list of all live streams associated with the current workspace. It provides an overview of both current and past live streams, including details like `streamId`, `metadata`, `status`, `createdAt` and more. # # # #### How it works # # Use the access token and secret key related to the workspace in the request header. When called, the API provides a paginated response containing all the live streams in that specific workspace. This is helpful for retrieving a large volume of streams and managing content in bulk. request = Models::Operations::GetAllStreamsRequest.new( limit: limit, offset: offset, order_by: order_by ) url, params = @sdk_configuration.get_server_details base_url = Utils.template_url(url, params) url = "#{base_url}/live/streams" headers = {} headers = T.cast(headers, T::Hash[String, String]) query_params = Utils.get_query_params(Models::Operations::GetAllStreamsRequest, request, nil) headers['Accept'] = CONTENT_TYPE_JSON headers[USER_AGENT_HEADER] = @sdk_configuration.user_agent security = @sdk_configuration.security_source&.call timeout = (timeout_ms.to_f / 1000) unless timeout_ms.nil? timeout ||= @sdk_configuration.timeout connection = @sdk_configuration.client hook_ctx = SDKHooks::HookContext.new( config: @sdk_configuration, base_url: base_url, oauth2_scopes: nil, operation_id: 'get-all-streams', security_source: @sdk_configuration.security_source ) error = T.let(nil, T.nilable(StandardError)) http_response = T.let(nil, T.nilable(Faraday::Response)) begin http_response = T.must(connection).get(url) do |req| req.headers.merge!(headers) req..timeout = timeout unless timeout.nil? req.params = query_params Utils.configure_request_security(req, security) @sdk_configuration.hooks.before_request( hook_ctx: SDKHooks::BeforeRequestHookContext.new( hook_ctx: hook_ctx ), request: req ) end rescue StandardError => e error = e ensure http_response = apply_after_request_hooks(http_response, error, hook_ctx) end content_type = http_response.headers.fetch(CONTENT_TYPE_HEADER, DEFAULT_CONTENT_TYPE) if Utils.match_status_code(http_response.status, ['200']) if Utils.match_content_type(content_type, CONTENT_TYPE_JSON) http_response = @sdk_configuration.hooks.after_success( hook_ctx: SDKHooks::AfterSuccessHookContext.new( hook_ctx: hook_ctx ), response: http_response ) response_data = http_response.env.response_body obj = Crystalline.unmarshal_json(JSON.parse(response_data), Models::Components::GetStreamsResponse) response = Models::Operations::GetAllStreamsResponse.new( status_code: http_response.status, content_type: content_type, raw_response: http_response, get_streams_response: T.unsafe(obj) ) return response else raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), UNKNOWN_CONTENT_TYPE_ERROR end elsif Utils.match_status_code(http_response.status, ['4XX']) raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), API_ERROR_OCCURRED elsif Utils.match_status_code(http_response.status, ['5XX']) raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), API_ERROR_OCCURRED else if Utils.match_content_type(content_type, CONTENT_TYPE_JSON) http_response = @sdk_configuration.hooks.after_success( hook_ctx: SDKHooks::AfterSuccessHookContext.new( hook_ctx: hook_ctx ), response: http_response ) response_data = http_response.env.response_body obj = Crystalline.unmarshal_json(JSON.parse(response_data), Models::Components::DefaultError) response = Models::Operations::GetAllStreamsResponse.new( status_code: http_response.status, content_type: content_type, raw_response: http_response, default_error: T.unsafe(obj) ) return response else raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), UNKNOWN_CONTENT_TYPE_ERROR end end end |
#get_live_stream_by_id(stream_id:, timeout_ms: nil) ⇒ Object
327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 |
# File 'lib/fastpix_client/manage_live_stream.rb', line 327 def get_live_stream_by_id(stream_id:, timeout_ms: nil) # get_live_stream_by_id - Get stream by ID # This endpoint retrieves details about a specific live stream by its unique `streamId`. It includes data such as the stream’s `status` (idle, preparing, active, disabled), `metadata` (title, description), and more. # #### Example # # Suppose a news agency is broadcasting a live event and wants to track the configurations set for the live stream while also checking the stream's status. # # # Related guide: <a href="https://fastpix.com/docs/manage-live-streams/create-and-manage-live-streams">Manage streams</a> request = Models::Operations::GetLiveStreamByIdRequest.new( stream_id: stream_id ) url, params = @sdk_configuration.get_server_details base_url = Utils.template_url(url, params) url = Utils.generate_url( Models::Operations::GetLiveStreamByIdRequest, base_url, STREAM_PATH, request ) headers = {} headers = T.cast(headers, T::Hash[String, String]) headers['Accept'] = CONTENT_TYPE_JSON headers[USER_AGENT_HEADER] = @sdk_configuration.user_agent security = @sdk_configuration.security_source&.call timeout = (timeout_ms.to_f / 1000) unless timeout_ms.nil? timeout ||= @sdk_configuration.timeout connection = @sdk_configuration.client hook_ctx = SDKHooks::HookContext.new( config: @sdk_configuration, base_url: base_url, oauth2_scopes: nil, operation_id: 'get-live-stream-by-id', security_source: @sdk_configuration.security_source ) error = T.let(nil, T.nilable(StandardError)) http_response = T.let(nil, T.nilable(Faraday::Response)) begin http_response = T.must(connection).get(url) do |req| req.headers.merge!(headers) req..timeout = timeout unless timeout.nil? Utils.configure_request_security(req, security) @sdk_configuration.hooks.before_request( hook_ctx: SDKHooks::BeforeRequestHookContext.new( hook_ctx: hook_ctx ), request: req ) end rescue StandardError => e error = e ensure http_response = apply_after_request_hooks(http_response, error, hook_ctx) end content_type = http_response.headers.fetch(CONTENT_TYPE_HEADER, DEFAULT_CONTENT_TYPE) if Utils.match_status_code(http_response.status, ['200']) if Utils.match_content_type(content_type, CONTENT_TYPE_JSON) http_response = @sdk_configuration.hooks.after_success( hook_ctx: SDKHooks::AfterSuccessHookContext.new( hook_ctx: hook_ctx ), response: http_response ) response_data = http_response.env.response_body obj = Crystalline.unmarshal_json(JSON.parse(response_data), Models::Components::LivestreamgetResponse) response = Models::Operations::GetLiveStreamByIdResponse.new( status_code: http_response.status, content_type: content_type, raw_response: http_response, livestreamget_response: T.unsafe(obj) ) return response else raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), UNKNOWN_CONTENT_TYPE_ERROR end elsif Utils.match_status_code(http_response.status, ['4XX']) raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), API_ERROR_OCCURRED elsif Utils.match_status_code(http_response.status, ['5XX']) raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), API_ERROR_OCCURRED else if Utils.match_content_type(content_type, CONTENT_TYPE_JSON) http_response = @sdk_configuration.hooks.after_success( hook_ctx: SDKHooks::AfterSuccessHookContext.new( hook_ctx: hook_ctx ), response: http_response ) response_data = http_response.env.response_body obj = Crystalline.unmarshal_json(JSON.parse(response_data), Models::Components::DefaultError) response = Models::Operations::GetLiveStreamByIdResponse.new( status_code: http_response.status, content_type: content_type, raw_response: http_response, default_error: T.unsafe(obj) ) return response else raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), UNKNOWN_CONTENT_TYPE_ERROR end end end |
#get_live_stream_viewer_count_by_id(stream_id:, timeout_ms: nil) ⇒ Object
209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 |
# File 'lib/fastpix_client/manage_live_stream.rb', line 209 def get_live_stream_viewer_count_by_id(stream_id:, timeout_ms: nil) # get_live_stream_viewer_count_by_id - Get stream views by ID # This endpoint retrieves the current number of viewers watching a specific live stream, identified by its unique `streamId`. # # The viewer count is an **approximate value**, optimized for performance. It provides a near-real-time estimate of how many clients are actively watching the stream. This approach ensures high efficiency, especially when the stream is being watched at large scale across multiple devices or platforms. # # #### Example # # Suppose a content creator is hosting a live concert and wants to display the number of live viewers on their dashboard. This endpoint can be queried to show up-to-date viewer statistics. # # Related guide: <a href="https://fastpix.com/docs/manage-live-streams/create-and-manage-live-streams">Manage streams</a> request = Models::Operations::GetLiveStreamViewerCountByIdRequest.new( stream_id: stream_id ) url, params = @sdk_configuration.get_server_details base_url = Utils.template_url(url, params) url = Utils.generate_url( Models::Operations::GetLiveStreamViewerCountByIdRequest, base_url, '/live/streams/{streamId}/viewer-count', request ) headers = {} headers = T.cast(headers, T::Hash[String, String]) headers['Accept'] = CONTENT_TYPE_JSON headers[USER_AGENT_HEADER] = @sdk_configuration.user_agent security = @sdk_configuration.security_source&.call timeout = (timeout_ms.to_f / 1000) unless timeout_ms.nil? timeout ||= @sdk_configuration.timeout connection = @sdk_configuration.client hook_ctx = SDKHooks::HookContext.new( config: @sdk_configuration, base_url: base_url, oauth2_scopes: nil, operation_id: 'get-live-stream-viewer-count-by-id', security_source: @sdk_configuration.security_source ) error = T.let(nil, T.nilable(StandardError)) http_response = T.let(nil, T.nilable(Faraday::Response)) begin http_response = T.must(connection).get(url) do |req| req.headers.merge!(headers) req..timeout = timeout unless timeout.nil? Utils.configure_request_security(req, security) @sdk_configuration.hooks.before_request( hook_ctx: SDKHooks::BeforeRequestHookContext.new( hook_ctx: hook_ctx ), request: req ) end rescue StandardError => e error = e ensure http_response = apply_after_request_hooks(http_response, error, hook_ctx) end content_type = http_response.headers.fetch(CONTENT_TYPE_HEADER, DEFAULT_CONTENT_TYPE) if Utils.match_status_code(http_response.status, ['200']) if Utils.match_content_type(content_type, CONTENT_TYPE_JSON) http_response = @sdk_configuration.hooks.after_success( hook_ctx: SDKHooks::AfterSuccessHookContext.new( hook_ctx: hook_ctx ), response: http_response ) response_data = http_response.env.response_body obj = Crystalline.unmarshal_json(JSON.parse(response_data), Models::Components::ViewsCountResponse) response = Models::Operations::GetLiveStreamViewerCountByIdResponse.new( status_code: http_response.status, content_type: content_type, raw_response: http_response, views_count_response: T.unsafe(obj) ) return response else raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), UNKNOWN_CONTENT_TYPE_ERROR end elsif Utils.match_status_code(http_response.status, ['4XX']) raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), API_ERROR_OCCURRED elsif Utils.match_status_code(http_response.status, ['5XX']) raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), API_ERROR_OCCURRED else if Utils.match_content_type(content_type, CONTENT_TYPE_JSON) http_response = @sdk_configuration.hooks.after_success( hook_ctx: SDKHooks::AfterSuccessHookContext.new( hook_ctx: hook_ctx ), response: http_response ) response_data = http_response.env.response_body obj = Crystalline.unmarshal_json(JSON.parse(response_data), Models::Components::DefaultError) response = Models::Operations::GetLiveStreamViewerCountByIdResponse.new( status_code: http_response.status, content_type: content_type, raw_response: http_response, default_error: T.unsafe(obj) ) return response else raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), UNKNOWN_CONTENT_TYPE_ERROR end end end |
#get_url(base_url:, url_variables: nil) ⇒ Object
79 80 81 82 83 84 85 86 87 88 89 90 91 |
# File 'lib/fastpix_client/manage_live_stream.rb', line 79 def get_url(base_url:, url_variables: nil) sd_base_url, = @sdk_configuration.get_server_details if base_url.nil? base_url = sd_base_url end if url_variables.nil? url_variables = end return Utils.template_url base_url, url_variables end |
#update_live_stream(body:, stream_id:, timeout_ms: nil) ⇒ Object
562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 |
# File 'lib/fastpix_client/manage_live_stream.rb', line 562 def update_live_stream(body:, stream_id:, timeout_ms: nil) # update_live_stream - Update a stream # This endpoint allows you to modify the parameters of an existing live stream, such as its `metadata` (title, description) or the `reconnectWindow`. It’s useful for making changes to a stream that has already been created but not yet ended. After the live stream is disabled, you cannot update a stream. # # # The updated stream parameters and the `streamId` needs to be shared in the request, and FastPix returns the updated stream details. After the update, <a href="https://fastpix.com/docs/live-stream-events/live-events#videolive_streamupdated">video.live_stream.updated</a> webhook event notifies your system. # # #### Example # # A host realizes they need to extend the reconnect window for their live stream in case they lose connection temporarily during the event. Or suppose during a multi-day online conference, the event organizers need to update the stream title to reflect the next day"s session while keeping the same stream ID for continuity. # # # # Related guide: <a href="https://fastpix.com/docs/manage-live-streams/create-and-manage-live-streams">Manage streams</a> request = Models::Operations::UpdateLiveStreamRequest.new( stream_id: stream_id, body: body ) url, params = @sdk_configuration.get_server_details base_url = Utils.template_url(url, params) url = Utils.generate_url( Models::Operations::UpdateLiveStreamRequest, base_url, STREAM_PATH, request ) headers = {} headers = T.cast(headers, T::Hash[String, String]) req_content_type, data, form = Utils.serialize_request_body(request, false, false, :body, :json) headers['content-type'] = req_content_type body = encode_request_body(req_content_type, data, form) headers['Accept'] = CONTENT_TYPE_JSON headers[USER_AGENT_HEADER] = @sdk_configuration.user_agent security = @sdk_configuration.security_source&.call timeout = (timeout_ms.to_f / 1000) unless timeout_ms.nil? timeout ||= @sdk_configuration.timeout connection = @sdk_configuration.client hook_ctx = SDKHooks::HookContext.new( config: @sdk_configuration, base_url: base_url, oauth2_scopes: nil, operation_id: 'update-live-stream', security_source: @sdk_configuration.security_source ) error = T.let(nil, T.nilable(StandardError)) http_response = T.let(nil, T.nilable(Faraday::Response)) begin http_response = T.must(connection).patch(url) do |req| req.body = body req.headers.merge!(headers) req..timeout = timeout unless timeout.nil? Utils.configure_request_security(req, security) @sdk_configuration.hooks.before_request( hook_ctx: SDKHooks::BeforeRequestHookContext.new( hook_ctx: hook_ctx ), request: req ) end rescue StandardError => e error = e ensure http_response = apply_after_request_hooks(http_response, error, hook_ctx) end content_type = http_response.headers.fetch(CONTENT_TYPE_HEADER, DEFAULT_CONTENT_TYPE) if Utils.match_status_code(http_response.status, ['200']) if Utils.match_content_type(content_type, CONTENT_TYPE_JSON) http_response = @sdk_configuration.hooks.after_success( hook_ctx: SDKHooks::AfterSuccessHookContext.new( hook_ctx: hook_ctx ), response: http_response ) response_data = http_response.env.response_body obj = Crystalline.unmarshal_json(JSON.parse(response_data), Models::Components::PatchResponseDTO) response = Models::Operations::UpdateLiveStreamResponse.new( status_code: http_response.status, content_type: content_type, raw_response: http_response, patch_response_dto: T.unsafe(obj) ) return response else raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), UNKNOWN_CONTENT_TYPE_ERROR end elsif Utils.match_status_code(http_response.status, ['4XX']) raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), API_ERROR_OCCURRED elsif Utils.match_status_code(http_response.status, ['5XX']) raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), API_ERROR_OCCURRED else if Utils.match_content_type(content_type, CONTENT_TYPE_JSON) http_response = @sdk_configuration.hooks.after_success( hook_ctx: SDKHooks::AfterSuccessHookContext.new( hook_ctx: hook_ctx ), response: http_response ) response_data = http_response.env.response_body obj = Crystalline.unmarshal_json(JSON.parse(response_data), Models::Components::DefaultError) response = Models::Operations::UpdateLiveStreamResponse.new( status_code: http_response.status, content_type: content_type, raw_response: http_response, default_error: T.unsafe(obj) ) return response else raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), UNKNOWN_CONTENT_TYPE_ERROR end end end |