Class: FastpixClient::Models::Components::WatermarkInput

Inherits:
Object
  • Object
show all
Extended by:
T::Sig
Includes:
Crystalline::MetadataFields
Defined in:
lib/fastpix_client/models/components/watermarkinput.rb

Overview

Contains configuration details for applying a watermark overlay to a video.
The watermark is placed over the media content during processing.
For detailed setup steps and customization options, refer to the FastPix Watermark Guide.

Instance Method Summary collapse

Methods included from Crystalline::MetadataFields

#field, #fields, included, #marshal_single, #to_dict, #to_json

Constructor Details

#initialize(type:, url:, placement: nil, width: nil, height: nil, opacity: nil) ⇒ WatermarkInput

Returns a new instance of WatermarkInput.



33
34
35
36
37
38
39
40
# File 'lib/fastpix_client/models/components/watermarkinput.rb', line 33

def initialize(type:, url:, placement: nil, width: nil, height: nil, opacity: nil)
  @type = type
  @url = url
  @placement = placement
  @width = width
  @height = height
  @opacity = opacity
end

Instance Method Details

#==(other) ⇒ Object



43
44
45
46
47
48
49
50
51
52
# File 'lib/fastpix_client/models/components/watermarkinput.rb', line 43

def ==(other)
  return false unless other.is_a? self.class
  return false unless @type == other.type
  return false unless @url == other.url
  return false unless @placement == other.placement
  return false unless @width == other.width
  return false unless @height == other.height
  return false unless @opacity == other.opacity
  true
end