Class: FastpixClient::Models::Operations::GetTimeseriesDataTimespan
- Inherits:
-
T::Enum
- Object
- T::Enum
- FastpixClient::Models::Operations::GetTimeseriesDataTimespan
- Defined in:
- lib/fastpix_client/models/operations/get_timeseries_data_timespan_.rb
Overview
GetTimeseriesDataTimespan - This parameter specifies the time span between which the video views list must be retrieved by. You can provide either from and to unix epoch timestamps or time duration. The scope of duration is between 60 minutes to 30 days.
Accepted formats are:
array of epoch timestamps for example
timespan[]=1498867200×pan[]=1498953600
duration string for example
timespan[]=24:hours or timespan[]=7:days