Class: FastpixClient::SimulcastStream
- Inherits:
-
Object
- Object
- FastpixClient::SimulcastStream
- Extended by:
- T::Sig
- Defined in:
- lib/fastpix_client/simulcast_stream.rb
Constant Summary collapse
- API_ERROR_OCCURRED =
'API error occurred'- CONTENT_TYPE_HEADER =
'Content-Type'- CONTENT_TYPE_JSON =
'application/json'- DEFAULT_CONTENT_TYPE =
'application/octet-stream'- SIMULCAST_PATH =
'/live/streams/{streamId}/simulcast/{simulcastId}'- UNKNOWN_CONTENT_TYPE_ERROR =
'Unknown content type received'- USER_AGENT_HEADER =
'user-agent'
Instance Method Summary collapse
- #create_simulcast_of_stream(body:, stream_id:, timeout_ms: nil) ⇒ Object
- #delete_simulcast_of_stream(stream_id:, simulcast_id:, timeout_ms: nil) ⇒ Object
- #get_specific_simulcast_of_stream(stream_id:, simulcast_id:, timeout_ms: nil) ⇒ Object
- #get_url(base_url:, url_variables: nil) ⇒ Object
-
#initialize(sdk_config) ⇒ SimulcastStream
constructor
A new instance of SimulcastStream.
- #update_specific_simulcast_of_stream(body:, stream_id:, simulcast_id:, timeout_ms: nil) ⇒ Object
Constructor Details
#initialize(sdk_config) ⇒ SimulcastStream
Returns a new instance of SimulcastStream.
73 74 75 76 |
# File 'lib/fastpix_client/simulcast_stream.rb', line 73 def initialize(sdk_config) @sdk_configuration = sdk_config end |
Instance Method Details
#create_simulcast_of_stream(body:, stream_id:, timeout_ms: nil) ⇒ Object
95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 |
# File 'lib/fastpix_client/simulcast_stream.rb', line 95 def create_simulcast_of_stream(body:, stream_id:, timeout_ms: nil) # create_simulcast_of_stream - Create a simulcast # Creates a simulcast for a parent live stream. Simulcasting allows you to broadcast a live stream to multiple social platforms simultaneously (for example, YouTube, Facebook, or Twitch). This helps expand your audience reach across platforms. A simulcast can only be created when the parent live stream is in the idle state (not currently live or disabled). Only one simulcast target can be created per API call. # #### How it works # # 1. Change to: When you call this endpoint, provide the parent `streamId` along with the simulcast target details (such as platform and credentials). The API returns a unique `simulcastId`, which you can use to manage the simulcast later. # # 2. To notify your application about the status of simulcast related events check for the <a href="https://fastpix.com/docs/webhooks/webhook-event-reference#simulcast-target-events">webhooks for simulcast</a> target events. # # #### Example # An event manager sets up a live stream for a virtual conference and wants to simulcast the stream on YouTube and Facebook Live. They first create the primary live stream in FastPix, ensuring it's in the idle state. Then, they use the API to create a simulcast target for YouTube. # # Related guide: <a href="https://fastpix.com/docs/edit-and-transform-live-stream/simulcast-to-multiple-platforms">Simulcast to 3rd party platforms</a> request = Models::Operations::CreateSimulcastOfStreamRequest.new( stream_id: stream_id, body: body ) url, params = @sdk_configuration.get_server_details base_url = Utils.template_url(url, params) url = Utils.generate_url( Models::Operations::CreateSimulcastOfStreamRequest, base_url, '/live/streams/{streamId}/simulcast', request ) headers = {} headers = T.cast(headers, T::Hash[String, String]) req_content_type, data, form = Utils.serialize_request_body(request, false, false, :body, :json) headers['content-type'] = req_content_type body = encode_request_body(req_content_type, data, form) headers['Accept'] = CONTENT_TYPE_JSON headers[USER_AGENT_HEADER] = @sdk_configuration.user_agent security = @sdk_configuration.security_source&.call timeout = (timeout_ms.to_f / 1000) unless timeout_ms.nil? timeout ||= @sdk_configuration.timeout connection = @sdk_configuration.client hook_ctx = SDKHooks::HookContext.new( config: @sdk_configuration, base_url: base_url, oauth2_scopes: nil, operation_id: 'create-simulcast-of-stream', security_source: @sdk_configuration.security_source ) error = T.let(nil, T.nilable(StandardError)) http_response = T.let(nil, T.nilable(Faraday::Response)) begin http_response = T.must(connection).post(url) do |req| req.body = body req.headers.merge!(headers) req..timeout = timeout unless timeout.nil? Utils.configure_request_security(req, security) @sdk_configuration.hooks.before_request( hook_ctx: SDKHooks::BeforeRequestHookContext.new( hook_ctx: hook_ctx ), request: req ) end rescue StandardError => e error = e ensure http_response = apply_after_request_hooks(http_response, error, hook_ctx) end content_type = http_response.headers.fetch(CONTENT_TYPE_HEADER, DEFAULT_CONTENT_TYPE) if Utils.match_status_code(http_response.status, ['201']) if Utils.match_content_type(content_type, CONTENT_TYPE_JSON) http_response = @sdk_configuration.hooks.after_success( hook_ctx: SDKHooks::AfterSuccessHookContext.new( hook_ctx: hook_ctx ), response: http_response ) response_data = http_response.env.response_body obj = Crystalline.unmarshal_json(JSON.parse(response_data), Models::Components::SimulcastResponse) response = Models::Operations::CreateSimulcastOfStreamResponse.new( status_code: http_response.status, content_type: content_type, raw_response: http_response, simulcast_response: T.unsafe(obj) ) return response else raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), UNKNOWN_CONTENT_TYPE_ERROR end elsif Utils.match_status_code(http_response.status, ['4XX']) raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), API_ERROR_OCCURRED elsif Utils.match_status_code(http_response.status, ['5XX']) raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), API_ERROR_OCCURRED else if Utils.match_content_type(content_type, CONTENT_TYPE_JSON) http_response = @sdk_configuration.hooks.after_success( hook_ctx: SDKHooks::AfterSuccessHookContext.new( hook_ctx: hook_ctx ), response: http_response ) response_data = http_response.env.response_body obj = Crystalline.unmarshal_json(JSON.parse(response_data), Models::Components::DefaultError) response = Models::Operations::CreateSimulcastOfStreamResponse.new( status_code: http_response.status, content_type: content_type, raw_response: http_response, default_error: T.unsafe(obj) ) return response else raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), UNKNOWN_CONTENT_TYPE_ERROR end end end |
#delete_simulcast_of_stream(stream_id:, simulcast_id:, timeout_ms: nil) ⇒ Object
220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 |
# File 'lib/fastpix_client/simulcast_stream.rb', line 220 def delete_simulcast_of_stream(stream_id:, simulcast_id:, timeout_ms: nil) # delete_simulcast_of_stream - Delete a simulcast # Deletes a simulcast using its unique simulcastId, which you received during the simulcast creation process. Deleting a simulcast stops the broadcast to the associated platform, while the parent stream continues if it’s live. This action can’t be undone, and you must create a new simulcast to resume streaming to the same platform. # # Webhook event: <a href="https://fastpix.com/docs/live-stream-events/live-events#videolive_streamsimulcast_targetdeleted">video.live_stream.simulcast_target.deleted</a> # # # #### Example # A broadcaster may need to stop simulcasting to one platform while keeping the stream active on others. For example, a tech company is simulcasting a product launch across multiple platforms. Midway through the event, they decide to stop the simulcast on Facebook due to performance issues but continue streaming on YouTube. They use this API to delete the Facebook simulcast target. request = Models::Operations::DeleteSimulcastOfStreamRequest.new( stream_id: stream_id, simulcast_id: simulcast_id ) url, params = @sdk_configuration.get_server_details base_url = Utils.template_url(url, params) url = Utils.generate_url( Models::Operations::DeleteSimulcastOfStreamRequest, base_url, SIMULCAST_PATH, request ) headers = {} headers = T.cast(headers, T::Hash[String, String]) headers['Accept'] = CONTENT_TYPE_JSON headers[USER_AGENT_HEADER] = @sdk_configuration.user_agent security = @sdk_configuration.security_source&.call timeout = (timeout_ms.to_f / 1000) unless timeout_ms.nil? timeout ||= @sdk_configuration.timeout connection = @sdk_configuration.client hook_ctx = SDKHooks::HookContext.new( config: @sdk_configuration, base_url: base_url, oauth2_scopes: nil, operation_id: 'delete-simulcast-of-stream', security_source: @sdk_configuration.security_source ) error = T.let(nil, T.nilable(StandardError)) http_response = T.let(nil, T.nilable(Faraday::Response)) begin http_response = T.must(connection).delete(url) do |req| req.headers.merge!(headers) req..timeout = timeout unless timeout.nil? Utils.configure_request_security(req, security) @sdk_configuration.hooks.before_request( hook_ctx: SDKHooks::BeforeRequestHookContext.new( hook_ctx: hook_ctx ), request: req ) end rescue StandardError => e error = e ensure http_response = apply_after_request_hooks(http_response, error, hook_ctx) end content_type = http_response.headers.fetch(CONTENT_TYPE_HEADER, DEFAULT_CONTENT_TYPE) if Utils.match_status_code(http_response.status, ['200']) if Utils.match_content_type(content_type, CONTENT_TYPE_JSON) http_response = @sdk_configuration.hooks.after_success( hook_ctx: SDKHooks::AfterSuccessHookContext.new( hook_ctx: hook_ctx ), response: http_response ) response_data = http_response.env.response_body obj = Crystalline.unmarshal_json(JSON.parse(response_data), Models::Components::SimulcastdeleteResponse) response = Models::Operations::DeleteSimulcastOfStreamResponse.new( status_code: http_response.status, content_type: content_type, raw_response: http_response, simulcastdelete_response: T.unsafe(obj) ) return response else raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), UNKNOWN_CONTENT_TYPE_ERROR end elsif Utils.match_status_code(http_response.status, ['4XX']) raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), API_ERROR_OCCURRED elsif Utils.match_status_code(http_response.status, ['5XX']) raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), API_ERROR_OCCURRED else if Utils.match_content_type(content_type, CONTENT_TYPE_JSON) http_response = @sdk_configuration.hooks.after_success( hook_ctx: SDKHooks::AfterSuccessHookContext.new( hook_ctx: hook_ctx ), response: http_response ) response_data = http_response.env.response_body obj = Crystalline.unmarshal_json(JSON.parse(response_data), Models::Components::DefaultError) response = Models::Operations::DeleteSimulcastOfStreamResponse.new( status_code: http_response.status, content_type: content_type, raw_response: http_response, default_error: T.unsafe(obj) ) return response else raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), UNKNOWN_CONTENT_TYPE_ERROR end end end |
#get_specific_simulcast_of_stream(stream_id:, simulcast_id:, timeout_ms: nil) ⇒ Object
337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 |
# File 'lib/fastpix_client/simulcast_stream.rb', line 337 def get_specific_simulcast_of_stream(stream_id:, simulcast_id:, timeout_ms: nil) # get_specific_simulcast_of_stream - Get a specific simulcast # Retrieves the details of a specific simulcast associated with a parent live stream. By providing both the `streamId` of the parent stream and the `simulcastId`, FastPix returns detailed information about the simulcast, such as the stream URL, the status of the simulcast, and metadata. # # #### Example # This endpoint can be used to verify the status of the simulcast on external platforms before the live stream begins. For example, before starting a live gaming event, the organizer wants to ensure that the simulcast to Twitch is set up correctly. They retrieve the simulcast information to confirm that everything is properly configured. request = Models::Operations::GetSpecificSimulcastOfStreamRequest.new( stream_id: stream_id, simulcast_id: simulcast_id ) url, params = @sdk_configuration.get_server_details base_url = Utils.template_url(url, params) url = Utils.generate_url( Models::Operations::GetSpecificSimulcastOfStreamRequest, base_url, SIMULCAST_PATH, request ) headers = {} headers = T.cast(headers, T::Hash[String, String]) headers['Accept'] = CONTENT_TYPE_JSON headers[USER_AGENT_HEADER] = @sdk_configuration.user_agent security = @sdk_configuration.security_source&.call timeout = (timeout_ms.to_f / 1000) unless timeout_ms.nil? timeout ||= @sdk_configuration.timeout connection = @sdk_configuration.client hook_ctx = SDKHooks::HookContext.new( config: @sdk_configuration, base_url: base_url, oauth2_scopes: nil, operation_id: 'get-specific-simulcast-of-stream', security_source: @sdk_configuration.security_source ) error = T.let(nil, T.nilable(StandardError)) http_response = T.let(nil, T.nilable(Faraday::Response)) begin http_response = T.must(connection).get(url) do |req| req.headers.merge!(headers) req..timeout = timeout unless timeout.nil? Utils.configure_request_security(req, security) @sdk_configuration.hooks.before_request( hook_ctx: SDKHooks::BeforeRequestHookContext.new( hook_ctx: hook_ctx ), request: req ) end rescue StandardError => e error = e ensure http_response = apply_after_request_hooks(http_response, error, hook_ctx) end content_type = http_response.headers.fetch(CONTENT_TYPE_HEADER, DEFAULT_CONTENT_TYPE) if Utils.match_status_code(http_response.status, ['200']) if Utils.match_content_type(content_type, CONTENT_TYPE_JSON) http_response = @sdk_configuration.hooks.after_success( hook_ctx: SDKHooks::AfterSuccessHookContext.new( hook_ctx: hook_ctx ), response: http_response ) response_data = http_response.env.response_body obj = Crystalline.unmarshal_json(JSON.parse(response_data), Models::Components::SimulcastResponse) response = Models::Operations::GetSpecificSimulcastOfStreamResponse.new( status_code: http_response.status, content_type: content_type, raw_response: http_response, simulcast_response: T.unsafe(obj) ) return response else raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), UNKNOWN_CONTENT_TYPE_ERROR end elsif Utils.match_status_code(http_response.status, ['4XX']) raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), API_ERROR_OCCURRED elsif Utils.match_status_code(http_response.status, ['5XX']) raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), API_ERROR_OCCURRED else if Utils.match_content_type(content_type, CONTENT_TYPE_JSON) http_response = @sdk_configuration.hooks.after_success( hook_ctx: SDKHooks::AfterSuccessHookContext.new( hook_ctx: hook_ctx ), response: http_response ) response_data = http_response.env.response_body obj = Crystalline.unmarshal_json(JSON.parse(response_data), Models::Components::DefaultError) response = Models::Operations::GetSpecificSimulcastOfStreamResponse.new( status_code: http_response.status, content_type: content_type, raw_response: http_response, default_error: T.unsafe(obj) ) return response else raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), UNKNOWN_CONTENT_TYPE_ERROR end end end |
#get_url(base_url:, url_variables: nil) ⇒ Object
79 80 81 82 83 84 85 86 87 88 89 90 91 |
# File 'lib/fastpix_client/simulcast_stream.rb', line 79 def get_url(base_url:, url_variables: nil) sd_base_url, = @sdk_configuration.get_server_details if base_url.nil? base_url = sd_base_url end if url_variables.nil? url_variables = end return Utils.template_url base_url, url_variables end |
#update_specific_simulcast_of_stream(body:, stream_id:, simulcast_id:, timeout_ms: nil) ⇒ Object
451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 |
# File 'lib/fastpix_client/simulcast_stream.rb', line 451 def update_specific_simulcast_of_stream(body:, stream_id:, simulcast_id:, timeout_ms: nil) # update_specific_simulcast_of_stream - Update a simulcast # Updates the status of a specific simulcast linked to a parent live stream. You can enable or disable the simulcast at any time while the parent stream is active or idle. After the live stream is disabled, the simulcast can no longer be modified. # # Webhook event: <a href="https://fastpix.com/docs/live-stream-events/live-events#videolive_streamsimulcast_targetupdated">video.live_stream.simulcast_target.updated</a> # # #### Example # When a `PATCH` request is made to this endpoint, the API updates the status of the simulcast. This can be useful for pausing or resuming a simulcast on a particular platform without stopping the parent live stream. request = Models::Operations::UpdateSpecificSimulcastOfStreamRequest.new( stream_id: stream_id, simulcast_id: simulcast_id, body: body ) url, params = @sdk_configuration.get_server_details base_url = Utils.template_url(url, params) url = Utils.generate_url( Models::Operations::UpdateSpecificSimulcastOfStreamRequest, base_url, SIMULCAST_PATH, request ) headers = {} headers = T.cast(headers, T::Hash[String, String]) req_content_type, data, form = Utils.serialize_request_body(request, false, false, :body, :json) headers['content-type'] = req_content_type body = encode_request_body(req_content_type, data, form) headers['Accept'] = CONTENT_TYPE_JSON headers[USER_AGENT_HEADER] = @sdk_configuration.user_agent security = @sdk_configuration.security_source&.call timeout = (timeout_ms.to_f / 1000) unless timeout_ms.nil? timeout ||= @sdk_configuration.timeout connection = @sdk_configuration.client hook_ctx = SDKHooks::HookContext.new( config: @sdk_configuration, base_url: base_url, oauth2_scopes: nil, operation_id: 'update-specific-simulcast-of-stream', security_source: @sdk_configuration.security_source ) error = T.let(nil, T.nilable(StandardError)) http_response = T.let(nil, T.nilable(Faraday::Response)) begin http_response = T.must(connection).put(url) do |req| req.body = body req.headers.merge!(headers) req..timeout = timeout unless timeout.nil? Utils.configure_request_security(req, security) @sdk_configuration.hooks.before_request( hook_ctx: SDKHooks::BeforeRequestHookContext.new( hook_ctx: hook_ctx ), request: req ) end rescue StandardError => e error = e ensure http_response = apply_after_request_hooks(http_response, error, hook_ctx) end content_type = http_response.headers.fetch(CONTENT_TYPE_HEADER, DEFAULT_CONTENT_TYPE) if Utils.match_status_code(http_response.status, ['200']) if Utils.match_content_type(content_type, CONTENT_TYPE_JSON) http_response = @sdk_configuration.hooks.after_success( hook_ctx: SDKHooks::AfterSuccessHookContext.new( hook_ctx: hook_ctx ), response: http_response ) response_data = http_response.env.response_body obj = Crystalline.unmarshal_json(JSON.parse(response_data), Models::Components::SimulcastUpdateResponse) response = Models::Operations::UpdateSpecificSimulcastOfStreamResponse.new( status_code: http_response.status, content_type: content_type, raw_response: http_response, simulcast_update_response: T.unsafe(obj) ) return response else raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), UNKNOWN_CONTENT_TYPE_ERROR end elsif Utils.match_status_code(http_response.status, ['4XX']) raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), API_ERROR_OCCURRED elsif Utils.match_status_code(http_response.status, ['5XX']) raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), API_ERROR_OCCURRED else if Utils.match_content_type(content_type, CONTENT_TYPE_JSON) http_response = @sdk_configuration.hooks.after_success( hook_ctx: SDKHooks::AfterSuccessHookContext.new( hook_ctx: hook_ctx ), response: http_response ) response_data = http_response.env.response_body obj = Crystalline.unmarshal_json(JSON.parse(response_data), Models::Components::DefaultError) response = Models::Operations::UpdateSpecificSimulcastOfStreamResponse.new( status_code: http_response.status, content_type: content_type, raw_response: http_response, default_error: T.unsafe(obj) ) return response else raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), UNKNOWN_CONTENT_TYPE_ERROR end end end |