Class: FastpixClient::Models::Components::DomainsDefaultPolicy
- Inherits:
-
T::Enum
- Object
- T::Enum
- FastpixClient::Models::Components::DomainsDefaultPolicy
- Defined in:
- lib/fastpix_client/models/components/domains_defaultpolicy.rb
Overview
DomainsDefaultPolicy - Specifies the default access policy for domains. If set to ‘allow`, all domains are allowed access unless otherwise specified in the `deny` lists. If set to `deny`, all domains are denied access unless otherwise specified in the `allow` lists.