Class: FastpixClient::Models::Components::UserAgentsDefaultPolicy
- Inherits:
-
T::Enum
- Object
- T::Enum
- FastpixClient::Models::Components::UserAgentsDefaultPolicy
- Defined in:
- lib/fastpix_client/models/components/useragents_defaultpolicy.rb
Overview
UserAgentsDefaultPolicy - Specifies the default access policy for user agents (browsers, bots, etc.). If set to ‘allow`, all user agents are allowed access unless otherwise specified in the `deny` lists. If set to `deny`, all user agents are denied access unless otherwise specified in the `allow` lists.