Class: FastpixClient::Models::Operations::DirectUploadVideoMediaUserAgentsDefaultPolicy
- Inherits:
-
T::Enum
- Object
- T::Enum
- FastpixClient::Models::Operations::DirectUploadVideoMediaUserAgentsDefaultPolicy
- Defined in:
- lib/fastpix_client/models/operations/direct_upload_video_media_useragents_defaultpolicy.rb
Overview
DirectUploadVideoMediaUserAgentsDefaultPolicy - Specifies the default access policy for user agents (browsers, bots, etc.).
If set to allow, all user agents are allowed access unless otherwise specified in the deny list.
If set to deny, all user agents are denied access unless otherwise specified in the allow list.