Class: FastpixClient::Playback
- Inherits:
-
Object
- Object
- FastpixClient::Playback
- Extended by:
- T::Sig
- Defined in:
- lib/fastpix_client/playback.rb
Instance Method Summary collapse
- #create_media_playback_id(body:, media_id:, timeout_ms: nil) ⇒ Object
- #delete_media_playback_id(media_id:, playback_id:, timeout_ms: nil) ⇒ Object
- #get_playback_id(media_id:, playback_id:, timeout_ms: nil) ⇒ Object
- #get_url(base_url:, url_variables: nil) ⇒ Object
-
#initialize(sdk_config) ⇒ Playback
constructor
A new instance of Playback.
- #list_playback_ids(media_id:, timeout_ms: nil) ⇒ Object
- #update_domain_restrictions(body:, media_id:, playback_id:, timeout_ms: nil) ⇒ Object
- #update_user_agent_restrictions(body:, media_id:, playback_id:, timeout_ms: nil) ⇒ Object
Constructor Details
#initialize(sdk_config) ⇒ Playback
Returns a new instance of Playback.
21 22 23 24 |
# File 'lib/fastpix_client/playback.rb', line 21 def initialize(sdk_config) @sdk_configuration = sdk_config end |
Instance Method Details
#create_media_playback_id(body:, media_id:, timeout_ms: nil) ⇒ Object
43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 |
# File 'lib/fastpix_client/playback.rb', line 43 def create_media_playback_id(body:, media_id:, timeout_ms: nil) # create_media_playback_id - Create a playback ID # You can create a new playback ID for a specific media asset. If you have already retrieved an existing `playbackId` using the <a href="https://docs.fastpix.io/reference/get-media">Get Media by ID</a> endpoint for a media asset, you can use this endpoint to generate a new playback ID with a specified access policy. # # # # If you want to create a private playback ID for a media asset that already has a public playback ID, this endpoint also allows you to do so by specifying the desired access policy. # # #### How it works # # 1. Make a `POST` request to this endpoint, replacing `<mediaId>` with the `uploadId` or `id` of the media asset. # # 2. Include the `accessPolicy` in the request body with `private` or `public` as the value. # # 3. You receive a response containing the newly created playback ID with the specified access level. # # # #### Example # A video streaming service generates playback IDs for each media file when users request to view specific content. The video player then uses the playback ID to stream the video. # request = Models::Operations::CreateMediaPlaybackIdRequest.new( media_id: media_id, body: body ) url, params = @sdk_configuration.get_server_details base_url = Utils.template_url(url, params) url = Utils.generate_url( Models::Operations::CreateMediaPlaybackIdRequest, base_url, '/on-demand/{mediaId}/playback-ids', request ) headers = {} headers = T.cast(headers, T::Hash[String, String]) req_content_type, data, form = Utils.serialize_request_body(request, false, false, :body, :json) headers['content-type'] = req_content_type raise StandardError, 'request body is required' if data.nil? && form.nil? if form body = Utils.encode_form(form) elsif Utils.match_content_type(req_content_type, 'application/x-www-form-urlencoded') body = URI.encode_www_form(T.cast(data, T::Hash[Symbol, Object])) else body = data end headers['Accept'] = 'application/json' headers['user-agent'] = @sdk_configuration.user_agent security = @sdk_configuration.security_source&.call timeout = (timeout_ms.to_f / 1000) unless timeout_ms.nil? timeout ||= @sdk_configuration.timeout connection = @sdk_configuration.client hook_ctx = SDKHooks::HookContext.new( config: @sdk_configuration, base_url: base_url, oauth2_scopes: nil, operation_id: 'create-media-playback-id', security_source: @sdk_configuration.security_source ) error = T.let(nil, T.nilable(StandardError)) http_response = T.let(nil, T.nilable(Faraday::Response)) begin http_response = T.must(connection).post(url) do |req| req.body = body req.headers.merge!(headers) req..timeout = timeout unless timeout.nil? Utils.configure_request_security(req, security) @sdk_configuration.hooks.before_request( hook_ctx: SDKHooks::BeforeRequestHookContext.new( hook_ctx: hook_ctx ), request: req ) end rescue StandardError => e error = e ensure if http_response.nil? || Utils.error_status?(http_response.status) http_response = @sdk_configuration.hooks.after_error( error: error, hook_ctx: SDKHooks::AfterErrorHookContext.new( hook_ctx: hook_ctx ), response: http_response ) else http_response = @sdk_configuration.hooks.after_success( hook_ctx: SDKHooks::AfterSuccessHookContext.new( hook_ctx: hook_ctx ), response: http_response ) end if http_response.nil? raise error if !error.nil? raise 'no response' end end content_type = http_response.headers.fetch('Content-Type', 'application/octet-stream') if Utils.match_status_code(http_response.status, ['201']) if Utils.match_content_type(content_type, 'application/json') http_response = @sdk_configuration.hooks.after_success( hook_ctx: SDKHooks::AfterSuccessHookContext.new( hook_ctx: hook_ctx ), response: http_response ) response_data = http_response.env.response_body obj = Crystalline.unmarshal_json(JSON.parse(response_data), Models::Operations::CreateMediaPlaybackIdResponseBody) response = Models::Operations::CreateMediaPlaybackIdResponse.new( status_code: http_response.status, content_type: content_type, raw_response: http_response, object: T.unsafe(obj) ) return response else raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), 'Unknown content type received' end elsif Utils.match_status_code(http_response.status, ['4XX']) raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), 'API error occurred' elsif Utils.match_status_code(http_response.status, ['5XX']) raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), 'API error occurred' else if Utils.match_content_type(content_type, 'application/json') http_response = @sdk_configuration.hooks.after_success( hook_ctx: SDKHooks::AfterSuccessHookContext.new( hook_ctx: hook_ctx ), response: http_response ) response_data = http_response.env.response_body obj = Crystalline.unmarshal_json(JSON.parse(response_data), Models::Components::DefaultError) response = Models::Operations::CreateMediaPlaybackIdResponse.new( status_code: http_response.status, content_type: content_type, raw_response: http_response, default_error: T.unsafe(obj) ) return response else raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), 'Unknown content type received' end end end |
#delete_media_playback_id(media_id:, playback_id:, timeout_ms: nil) ⇒ Object
341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 |
# File 'lib/fastpix_client/playback.rb', line 341 def delete_media_playback_id(media_id:, playback_id:, timeout_ms: nil) # delete_media_playback_id - Delete a playback ID # This endpoint deletes a specific playback ID associated with a media asset. Deleting a `playback ID` revokes access to the media content linked to that ID. # # # #### How it works # # 1. Make a `DELETE` request to this endpoint, replacing `<mediaId>` with the unique ID of the media asset from which you want to delete the playback ID. # # 2. Include the `playbackId` you want to delete in the request body. # # #### Example # # Your platform offers limited-time access to premium content. When the subscription expires, you can revoke access to the content by deleting the associated playback ID, preventing users from streaming the video further. # request = Models::Operations::DeleteMediaPlaybackIdRequest.new( media_id: media_id, playback_id: playback_id ) url, params = @sdk_configuration.get_server_details base_url = Utils.template_url(url, params) url = Utils.generate_url( Models::Operations::DeleteMediaPlaybackIdRequest, base_url, '/on-demand/{mediaId}/playback-ids', request ) headers = {} headers = T.cast(headers, T::Hash[String, String]) query_params = Utils.get_query_params(Models::Operations::DeleteMediaPlaybackIdRequest, request, nil) headers['Accept'] = 'application/json' headers['user-agent'] = @sdk_configuration.user_agent security = @sdk_configuration.security_source&.call timeout = (timeout_ms.to_f / 1000) unless timeout_ms.nil? timeout ||= @sdk_configuration.timeout connection = @sdk_configuration.client hook_ctx = SDKHooks::HookContext.new( config: @sdk_configuration, base_url: base_url, oauth2_scopes: nil, operation_id: 'delete-media-playback-id', security_source: @sdk_configuration.security_source ) error = T.let(nil, T.nilable(StandardError)) http_response = T.let(nil, T.nilable(Faraday::Response)) begin http_response = T.must(connection).delete(url) do |req| req.headers.merge!(headers) req..timeout = timeout unless timeout.nil? req.params = query_params Utils.configure_request_security(req, security) @sdk_configuration.hooks.before_request( hook_ctx: SDKHooks::BeforeRequestHookContext.new( hook_ctx: hook_ctx ), request: req ) end rescue StandardError => e error = e ensure if http_response.nil? || Utils.error_status?(http_response.status) http_response = @sdk_configuration.hooks.after_error( error: error, hook_ctx: SDKHooks::AfterErrorHookContext.new( hook_ctx: hook_ctx ), response: http_response ) else http_response = @sdk_configuration.hooks.after_success( hook_ctx: SDKHooks::AfterSuccessHookContext.new( hook_ctx: hook_ctx ), response: http_response ) end if http_response.nil? raise error if !error.nil? raise 'no response' end end content_type = http_response.headers.fetch('Content-Type', 'application/octet-stream') if Utils.match_status_code(http_response.status, ['200']) if Utils.match_content_type(content_type, 'application/json') http_response = @sdk_configuration.hooks.after_success( hook_ctx: SDKHooks::AfterSuccessHookContext.new( hook_ctx: hook_ctx ), response: http_response ) response_data = http_response.env.response_body obj = Crystalline.unmarshal_json(JSON.parse(response_data), Models::Operations::DeleteMediaPlaybackIdResponseBody) response = Models::Operations::DeleteMediaPlaybackIdResponse.new( status_code: http_response.status, content_type: content_type, raw_response: http_response, object: T.unsafe(obj) ) return response else raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), 'Unknown content type received' end elsif Utils.match_status_code(http_response.status, ['4XX']) raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), 'API error occurred' elsif Utils.match_status_code(http_response.status, ['5XX']) raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), 'API error occurred' else if Utils.match_content_type(content_type, 'application/json') http_response = @sdk_configuration.hooks.after_success( hook_ctx: SDKHooks::AfterSuccessHookContext.new( hook_ctx: hook_ctx ), response: http_response ) response_data = http_response.env.response_body obj = Crystalline.unmarshal_json(JSON.parse(response_data), Models::Components::DefaultError) response = Models::Operations::DeleteMediaPlaybackIdResponse.new( status_code: http_response.status, content_type: content_type, raw_response: http_response, default_error: T.unsafe(obj) ) return response else raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), 'Unknown content type received' end end end |
#get_playback_id(media_id:, playback_id:, timeout_ms: nil) ⇒ Object
486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 |
# File 'lib/fastpix_client/playback.rb', line 486 def get_playback_id(media_id:, playback_id:, timeout_ms: nil) # get_playback_id - Get a playback ID # This endpoint retrieves details about a specific playback ID associated with a media asset. Use it to check the access policy for that specific playback ID, such as whether it is public or private. # # **How it works:** # 1. Make a GET request to the endpoint, replacing `{mediaId}` with the media ID and `{playbackId}` with the playback ID. # 2. This request is useful for auditing or validation before granting playback access in your application. # # **Example:** # A media platform might use this endpoint to verify if a playback ID is public or private before embedding the video in a frontend player or allowing access to a restricted group. # request = Models::Operations::GetPlaybackIdRequest.new( media_id: media_id, playback_id: playback_id ) url, params = @sdk_configuration.get_server_details base_url = Utils.template_url(url, params) url = Utils.generate_url( Models::Operations::GetPlaybackIdRequest, base_url, '/on-demand/{mediaId}/playback-ids/{playbackId}', request ) headers = {} headers = T.cast(headers, T::Hash[String, String]) headers['Accept'] = 'application/json' headers['user-agent'] = @sdk_configuration.user_agent security = @sdk_configuration.security_source&.call timeout = (timeout_ms.to_f / 1000) unless timeout_ms.nil? timeout ||= @sdk_configuration.timeout connection = @sdk_configuration.client hook_ctx = SDKHooks::HookContext.new( config: @sdk_configuration, base_url: base_url, oauth2_scopes: nil, operation_id: 'get-playback-id', security_source: @sdk_configuration.security_source ) error = T.let(nil, T.nilable(StandardError)) http_response = T.let(nil, T.nilable(Faraday::Response)) begin http_response = T.must(connection).get(url) do |req| req.headers.merge!(headers) req..timeout = timeout unless timeout.nil? Utils.configure_request_security(req, security) @sdk_configuration.hooks.before_request( hook_ctx: SDKHooks::BeforeRequestHookContext.new( hook_ctx: hook_ctx ), request: req ) end rescue StandardError => e error = e ensure if http_response.nil? || Utils.error_status?(http_response.status) http_response = @sdk_configuration.hooks.after_error( error: error, hook_ctx: SDKHooks::AfterErrorHookContext.new( hook_ctx: hook_ctx ), response: http_response ) else http_response = @sdk_configuration.hooks.after_success( hook_ctx: SDKHooks::AfterSuccessHookContext.new( hook_ctx: hook_ctx ), response: http_response ) end if http_response.nil? raise error if !error.nil? raise 'no response' end end content_type = http_response.headers.fetch('Content-Type', 'application/octet-stream') if Utils.match_status_code(http_response.status, ['200']) if Utils.match_content_type(content_type, 'application/json') http_response = @sdk_configuration.hooks.after_success( hook_ctx: SDKHooks::AfterSuccessHookContext.new( hook_ctx: hook_ctx ), response: http_response ) response_data = http_response.env.response_body obj = Crystalline.unmarshal_json(JSON.parse(response_data), Models::Operations::GetPlaybackIdResponseBody) response = Models::Operations::GetPlaybackIdResponse.new( status_code: http_response.status, content_type: content_type, raw_response: http_response, object: T.unsafe(obj) ) return response else raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), 'Unknown content type received' end elsif Utils.match_status_code(http_response.status, ['4XX']) raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), 'API error occurred' elsif Utils.match_status_code(http_response.status, ['5XX']) raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), 'API error occurred' else if Utils.match_content_type(content_type, 'application/json') http_response = @sdk_configuration.hooks.after_success( hook_ctx: SDKHooks::AfterSuccessHookContext.new( hook_ctx: hook_ctx ), response: http_response ) response_data = http_response.env.response_body obj = Crystalline.unmarshal_json(JSON.parse(response_data), Models::Components::DefaultError) response = Models::Operations::GetPlaybackIdResponse.new( status_code: http_response.status, content_type: content_type, raw_response: http_response, default_error: T.unsafe(obj) ) return response else raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), 'Unknown content type received' end end end |
#get_url(base_url:, url_variables: nil) ⇒ Object
27 28 29 30 31 32 33 34 35 36 37 38 39 |
# File 'lib/fastpix_client/playback.rb', line 27 def get_url(base_url:, url_variables: nil) sd_base_url, = @sdk_configuration.get_server_details if base_url.nil? base_url = sd_base_url end if url_variables.nil? url_variables = end return Utils.template_url base_url, url_variables end |
#list_playback_ids(media_id:, timeout_ms: nil) ⇒ Object
203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 |
# File 'lib/fastpix_client/playback.rb', line 203 def list_playback_ids(media_id:, timeout_ms: nil) # list_playback_ids - Get all playback IDs details for a media # Retrieves all playback IDs associated with a given media asset, including each playback ID’s access policy and detailed access restrictions such as allowed or denied domains and user agents. # # **How it works:** # 1. Send a `GET` request to this endpoint with the target `mediaId`. # 2. The response includes an array of playback ID records with their respective access controls. # # **Use case:** # Useful for validating and managing playback permissions programmatically, reviewing restriction settings, or powering an access control dashboard. # request = Models::Operations::ListPlaybackIdsRequest.new( media_id: media_id ) url, params = @sdk_configuration.get_server_details base_url = Utils.template_url(url, params) url = Utils.generate_url( Models::Operations::ListPlaybackIdsRequest, base_url, '/on-demand/{mediaId}/playback-ids', request ) headers = {} headers = T.cast(headers, T::Hash[String, String]) headers['Accept'] = 'application/json' headers['user-agent'] = @sdk_configuration.user_agent security = @sdk_configuration.security_source&.call timeout = (timeout_ms.to_f / 1000) unless timeout_ms.nil? timeout ||= @sdk_configuration.timeout connection = @sdk_configuration.client hook_ctx = SDKHooks::HookContext.new( config: @sdk_configuration, base_url: base_url, oauth2_scopes: nil, operation_id: 'list-playback-ids', security_source: @sdk_configuration.security_source ) error = T.let(nil, T.nilable(StandardError)) http_response = T.let(nil, T.nilable(Faraday::Response)) begin http_response = T.must(connection).get(url) do |req| req.headers.merge!(headers) req..timeout = timeout unless timeout.nil? Utils.configure_request_security(req, security) @sdk_configuration.hooks.before_request( hook_ctx: SDKHooks::BeforeRequestHookContext.new( hook_ctx: hook_ctx ), request: req ) end rescue StandardError => e error = e ensure if http_response.nil? || Utils.error_status?(http_response.status) http_response = @sdk_configuration.hooks.after_error( error: error, hook_ctx: SDKHooks::AfterErrorHookContext.new( hook_ctx: hook_ctx ), response: http_response ) else http_response = @sdk_configuration.hooks.after_success( hook_ctx: SDKHooks::AfterSuccessHookContext.new( hook_ctx: hook_ctx ), response: http_response ) end if http_response.nil? raise error if !error.nil? raise 'no response' end end content_type = http_response.headers.fetch('Content-Type', 'application/octet-stream') if Utils.match_status_code(http_response.status, ['200']) if Utils.match_content_type(content_type, 'application/json') http_response = @sdk_configuration.hooks.after_success( hook_ctx: SDKHooks::AfterSuccessHookContext.new( hook_ctx: hook_ctx ), response: http_response ) response_data = http_response.env.response_body obj = Crystalline.unmarshal_json(JSON.parse(response_data), Models::Operations::ListPlaybackIdsResponseBody) response = Models::Operations::ListPlaybackIdsResponse.new( status_code: http_response.status, content_type: content_type, raw_response: http_response, object: T.unsafe(obj) ) return response else raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), 'Unknown content type received' end elsif Utils.match_status_code(http_response.status, ['4XX']) raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), 'API error occurred' elsif Utils.match_status_code(http_response.status, ['5XX']) raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), 'API error occurred' else if Utils.match_content_type(content_type, 'application/json') http_response = @sdk_configuration.hooks.after_success( hook_ctx: SDKHooks::AfterSuccessHookContext.new( hook_ctx: hook_ctx ), response: http_response ) response_data = http_response.env.response_body obj = Crystalline.unmarshal_json(JSON.parse(response_data), Models::Components::DefaultError) response = Models::Operations::ListPlaybackIdsResponse.new( status_code: http_response.status, content_type: content_type, raw_response: http_response, default_error: T.unsafe(obj) ) return response else raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), 'Unknown content type received' end end end |
#update_domain_restrictions(body:, media_id:, playback_id:, timeout_ms: nil) ⇒ Object
625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 |
# File 'lib/fastpix_client/playback.rb', line 625 def update_domain_restrictions(body:, media_id:, playback_id:, timeout_ms: nil) # update_domain_restrictions - Update domain restrictions for a playback ID # This endpoint updates domain-level restrictions for a specific playback ID associated with a media asset. # It allows you to restrict playback to specific domains or block known unauthorized domains. # # **How it works:** # 1. Make a `PATCH` request to this endpoint with your desired domain access configuration. # 2. Set a default policy (`allow` or `deny`) and specify domain names in the `allow` or `deny` lists. # 3. This is commonly used to restrict video playback to your website or approved client domains. # # **Example:** # A streaming service can allow playback only from `example.com` and deny all others by setting: `"defaultPolicy": "deny"` and `"allow": ["example.com"]`. # request = Models::Operations::UpdateDomainRestrictionsRequest.new( media_id: media_id, playback_id: playback_id, body: body ) url, params = @sdk_configuration.get_server_details base_url = Utils.template_url(url, params) url = Utils.generate_url( Models::Operations::UpdateDomainRestrictionsRequest, base_url, '/on-demand/{mediaId}/playback-ids/{playbackId}/domains', request ) headers = {} headers = T.cast(headers, T::Hash[String, String]) req_content_type, data, form = Utils.serialize_request_body(request, false, false, :body, :json) headers['content-type'] = req_content_type raise StandardError, 'request body is required' if data.nil? && form.nil? if form body = Utils.encode_form(form) elsif Utils.match_content_type(req_content_type, 'application/x-www-form-urlencoded') body = URI.encode_www_form(T.cast(data, T::Hash[Symbol, Object])) else body = data end headers['Accept'] = 'application/json' headers['user-agent'] = @sdk_configuration.user_agent security = @sdk_configuration.security_source&.call timeout = (timeout_ms.to_f / 1000) unless timeout_ms.nil? timeout ||= @sdk_configuration.timeout connection = @sdk_configuration.client hook_ctx = SDKHooks::HookContext.new( config: @sdk_configuration, base_url: base_url, oauth2_scopes: nil, operation_id: 'update-domain-restrictions', security_source: @sdk_configuration.security_source ) error = T.let(nil, T.nilable(StandardError)) http_response = T.let(nil, T.nilable(Faraday::Response)) begin http_response = T.must(connection).patch(url) do |req| req.body = body req.headers.merge!(headers) req..timeout = timeout unless timeout.nil? Utils.configure_request_security(req, security) @sdk_configuration.hooks.before_request( hook_ctx: SDKHooks::BeforeRequestHookContext.new( hook_ctx: hook_ctx ), request: req ) end rescue StandardError => e error = e ensure if http_response.nil? || Utils.error_status?(http_response.status) http_response = @sdk_configuration.hooks.after_error( error: error, hook_ctx: SDKHooks::AfterErrorHookContext.new( hook_ctx: hook_ctx ), response: http_response ) else http_response = @sdk_configuration.hooks.after_success( hook_ctx: SDKHooks::AfterSuccessHookContext.new( hook_ctx: hook_ctx ), response: http_response ) end if http_response.nil? raise error if !error.nil? raise 'no response' end end content_type = http_response.headers.fetch('Content-Type', 'application/octet-stream') if Utils.match_status_code(http_response.status, ['200']) if Utils.match_content_type(content_type, 'application/json') http_response = @sdk_configuration.hooks.after_success( hook_ctx: SDKHooks::AfterSuccessHookContext.new( hook_ctx: hook_ctx ), response: http_response ) response_data = http_response.env.response_body obj = Crystalline.unmarshal_json(JSON.parse(response_data), Models::Operations::UpdateDomainRestrictionsResponseBody) response = Models::Operations::UpdateDomainRestrictionsResponse.new( status_code: http_response.status, content_type: content_type, raw_response: http_response, object: T.unsafe(obj) ) return response else raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), 'Unknown content type received' end elsif Utils.match_status_code(http_response.status, ['4XX']) raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), 'API error occurred' elsif Utils.match_status_code(http_response.status, ['5XX']) raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), 'API error occurred' else if Utils.match_content_type(content_type, 'application/json') http_response = @sdk_configuration.hooks.after_success( hook_ctx: SDKHooks::AfterSuccessHookContext.new( hook_ctx: hook_ctx ), response: http_response ) response_data = http_response.env.response_body obj = Crystalline.unmarshal_json(JSON.parse(response_data), Models::Components::DefaultError) response = Models::Operations::UpdateDomainRestrictionsResponse.new( status_code: http_response.status, content_type: content_type, raw_response: http_response, default_error: T.unsafe(obj) ) return response else raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), 'Unknown content type received' end end end |
#update_user_agent_restrictions(body:, media_id:, playback_id:, timeout_ms: nil) ⇒ Object
779 780 781 782 783 784 785 786 787 788 789 790 791 792 793 794 795 796 797 798 799 800 801 802 803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 868 869 870 871 872 873 874 875 876 877 878 879 880 881 882 883 884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 |
# File 'lib/fastpix_client/playback.rb', line 779 def update_user_agent_restrictions(body:, media_id:, playback_id:, timeout_ms: nil) # update_user_agent_restrictions - Update user-agent restrictions for a playback ID # This endpoint allows updating user-agent restrictions for a specific playback ID associated with a media asset. # It can be used to allow or deny specific user-agents during playback request evaluation. # # **How it works:** # 1. Make a `PATCH` request to this endpoint with your desired user-agent access configuration. # 2. Specify a default policy (`allow` or `deny`) and provide specific `allow` or `deny` lists. # 3. Use this to restrict access to specific browsers, devices, or bots. # # **Example:** # A developer may configure a playback ID to deny access from known scraping user-agents while allowing all others by default. # request = Models::Operations::UpdateUserAgentRestrictionsRequest.new( media_id: media_id, playback_id: playback_id, body: body ) url, params = @sdk_configuration.get_server_details base_url = Utils.template_url(url, params) url = Utils.generate_url( Models::Operations::UpdateUserAgentRestrictionsRequest, base_url, '/on-demand/{mediaId}/playback-ids/{playbackId}/user-agents', request ) headers = {} headers = T.cast(headers, T::Hash[String, String]) req_content_type, data, form = Utils.serialize_request_body(request, false, false, :body, :json) headers['content-type'] = req_content_type raise StandardError, 'request body is required' if data.nil? && form.nil? if form body = Utils.encode_form(form) elsif Utils.match_content_type(req_content_type, 'application/x-www-form-urlencoded') body = URI.encode_www_form(T.cast(data, T::Hash[Symbol, Object])) else body = data end headers['Accept'] = 'application/json' headers['user-agent'] = @sdk_configuration.user_agent security = @sdk_configuration.security_source&.call timeout = (timeout_ms.to_f / 1000) unless timeout_ms.nil? timeout ||= @sdk_configuration.timeout connection = @sdk_configuration.client hook_ctx = SDKHooks::HookContext.new( config: @sdk_configuration, base_url: base_url, oauth2_scopes: nil, operation_id: 'update-user-agent-restrictions', security_source: @sdk_configuration.security_source ) error = T.let(nil, T.nilable(StandardError)) http_response = T.let(nil, T.nilable(Faraday::Response)) begin http_response = T.must(connection).patch(url) do |req| req.body = body req.headers.merge!(headers) req..timeout = timeout unless timeout.nil? Utils.configure_request_security(req, security) @sdk_configuration.hooks.before_request( hook_ctx: SDKHooks::BeforeRequestHookContext.new( hook_ctx: hook_ctx ), request: req ) end rescue StandardError => e error = e ensure if http_response.nil? || Utils.error_status?(http_response.status) http_response = @sdk_configuration.hooks.after_error( error: error, hook_ctx: SDKHooks::AfterErrorHookContext.new( hook_ctx: hook_ctx ), response: http_response ) else http_response = @sdk_configuration.hooks.after_success( hook_ctx: SDKHooks::AfterSuccessHookContext.new( hook_ctx: hook_ctx ), response: http_response ) end if http_response.nil? raise error if !error.nil? raise 'no response' end end content_type = http_response.headers.fetch('Content-Type', 'application/octet-stream') if Utils.match_status_code(http_response.status, ['200']) if Utils.match_content_type(content_type, 'application/json') http_response = @sdk_configuration.hooks.after_success( hook_ctx: SDKHooks::AfterSuccessHookContext.new( hook_ctx: hook_ctx ), response: http_response ) response_data = http_response.env.response_body obj = Crystalline.unmarshal_json(JSON.parse(response_data), Models::Operations::UpdateUserAgentRestrictionsResponseBody) response = Models::Operations::UpdateUserAgentRestrictionsResponse.new( status_code: http_response.status, content_type: content_type, raw_response: http_response, object: T.unsafe(obj) ) return response else raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), 'Unknown content type received' end elsif Utils.match_status_code(http_response.status, ['4XX']) raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), 'API error occurred' elsif Utils.match_status_code(http_response.status, ['5XX']) raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), 'API error occurred' else if Utils.match_content_type(content_type, 'application/json') http_response = @sdk_configuration.hooks.after_success( hook_ctx: SDKHooks::AfterSuccessHookContext.new( hook_ctx: hook_ctx ), response: http_response ) response_data = http_response.env.response_body obj = Crystalline.unmarshal_json(JSON.parse(response_data), Models::Components::DefaultError) response = Models::Operations::UpdateUserAgentRestrictionsResponse.new( status_code: http_response.status, content_type: content_type, raw_response: http_response, default_error: T.unsafe(obj) ) return response else raise ::FastpixClient::Models::Errors::APIError.new(status_code: http_response.status, body: http_response.env.response_body, raw_response: http_response), 'Unknown content type received' end end end |